"""
Tests
"""

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.legacy_bots.sport_lab_suffixes import get_teams_new

get_teams_new_data = {
    "international cricket records and statistics": "سجلات وإحصائيات كريكت دولية",
    "sports cup competitions": "منافسات كؤوس رياضية",
    "international men's football competitions": "منافسات كرة قدم دولية للرجال",
    "international women's basketball competitions": "منافسات كرة سلة دولية للسيدات",
    "international women's cricket competitions": "منافسات كريكت دولية للسيدات",
    "international women's field hockey competitions": "منافسات هوكي ميدان دولية للسيدات",
    "international women's football competitions": "منافسات كرة قدم دولية للسيدات",
    "under-13 equestrian manager history": "تاريخ مدربو فروسية تحت 13 سنة",
    "under-14 equestrian manager history": "تاريخ مدربو فروسية تحت 14 سنة",
    "soccer cup competitions": "منافسات كؤوس كرة قدم",
    "national youth baseball teams": "منتخبات كرة قاعدة وطنية شبابية",
    "national youth basketball teams": "منتخبات كرة سلة وطنية شبابية",
    "australian rules football awards": "جوائز كرة قدم أسترالية",
    "badminton world cup": "كأس العالم لتنس الريشة",
    "baseball commissioners": "مفوضو كرة قاعدة",
    "baseball music": "موسيقى كرة قاعدة",
    "baseball video games": "ألعاب فيديو كرة قاعدة",
    "basketball awards": "جوائز كرة سلة",
    "basketball comics": "قصص مصورة كرة سلة",
    "basketball cup competitions": "منافسات كؤوس كرة سلة",
    "basketball league": "دوري كرة السلة",
    "basketball terminology": "مصطلحات كرة سلة",
    "biathlon world cup": "كأس العالم للبياثلون",
    "bowling broadcasters": "مذيعو بولينج",
    "bowling television series": "مسلسلات تلفزيونية بولينج",
    "boxing world cup": "كأس العالم للبوكسينغ",
    "canoeing logos": "شعارات ركوب الكنو",
    "current football seasons": "مواسم كرة قدم حالية",
    "cycling races": "سباقات سباق دراجات هوائية",
    "cycling television series": "مسلسلات تلفزيونية سباق دراجات هوائية",
    "defunct american football teams": "فرق كرة قدم أمريكية سابقة",
    "defunct baseball leagues": "دوريات كرة قاعدة سابقة",
    "defunct baseball teams": "فرق كرة قاعدة سابقة",
    "defunct basketball competitions": "منافسات كرة سلة سابقة",
    "defunct basketball teams": "فرق كرة سلة سابقة",
    "defunct cycling teams": "فرق سباق دراجات هوائية سابقة",
    "defunct esports competitions": "منافسات رياضة إلكترونية سابقة",
    "defunct football clubs": "أندية كرة قدم سابقة",
    "defunct football competitions": "منافسات كرة قدم سابقة",
    "defunct football cup competitions": "منافسات كؤوس كرة قدم سابقة",
    "defunct football cups": "كؤوس كرة قدم سابقة",
    "defunct football leagues": "دوريات كرة قدم سابقة",
    "defunct gaelic football competitions": "منافسات كرة قدم غالية سابقة",
    "defunct hockey competitions": "منافسات هوكي سابقة",
    "defunct ice hockey leagues": "دوريات هوكي جليد سابقة",
    "defunct ice hockey teams": "فرق هوكي جليد سابقة",
    "defunct indoor soccer leagues": "دوريات كرة قدم داخل الصالات سابقة",
    "defunct netball leagues": "دوريات كرة شبكة سابقة",
    "defunct rugby league teams": "فرق دوري رجبي سابقة",
    "defunct rugby union cup competitions": "منافسات كؤوس اتحاد رجبي سابقة",
    "defunct rugby union leagues": "دوريات اتحاد رجبي سابقة",
    "defunct rugby union teams": "فرق اتحاد رجبي سابقة",
    "defunct soccer clubs": "أندية كرة قدم سابقة",
    "defunct sports clubs": "أندية رياضية سابقة",
    "defunct sports competitions": "منافسات رياضية سابقة",
    "defunct sports leagues": "دوريات رياضية سابقة",
    "defunct water polo clubs": "أندية كرة ماء سابقة",
    "defunct water polo competitions": "منافسات كرة ماء سابقة",
    "domestic cricket competitions": "منافسات كريكت محلية",
    "domestic football cup": "كؤوس كرة قدم محلية",
    "domestic football cups": "كؤوس كرة قدم محلية",
    "domestic football leagues": "دوريات كرة قدم محلية",
    "domestic football": "كرة قدم محلية",
    "domestic handball leagues": "دوريات كرة يد محلية",
    "domestic women's football leagues": "دوريات كرة قدم محلية للسيدات",
    "fencing logos": "شعارات مبارزة سيف شيش",
    "first-class cricket": "كريكت من الدرجة الأولى",
    "football chairmen and investors": "رؤساء ومسيرو كرة قدم",
    "football cup competitions": "منافسات كؤوس كرة قدم",
    "football cups": "كؤوس كرة قدم",
    "football governing bodies": "هيئات تنظيم كرة قدم",
    "football league": "دوري كرة القدم",
    "go comics": "قصص مصورة غو",
    "indoor football": "كرة قدم داخل الصالات",
    "indoor hockey": "هوكي داخل الصالات",
    "indoor track and field": "سباقات مضمار وميدان داخل الصالات",
    "international aquatics competitions": "منافسات رياضات مائية دولية",
    "international archery competitions": "منافسات نبالة دولية",
    "international athletics competitions": "منافسات ألعاب قوى دولية",
    "international bandy competitions": "منافسات باندي دولية",
    "international baseball competitions": "منافسات كرة قاعدة دولية",
    "international basketball competitions": "منافسات كرة سلة دولية",
    "international boxing competitions": "منافسات بوكسينغ دولية",
    "international cricket competitions": "منافسات كريكت دولية",
    "international cycle races": "سباقات دراجات دولية",
    "international fencing competitions": "منافسات مبارزة سيف شيش دولية",
    "international field hockey competitions": "منافسات هوكي ميدان دولية",
    "international figure skating competitions": "منافسات تزلج فني دولية",
    "international football competitions": "منافسات كرة قدم دولية",
    "international futsal competitions": "منافسات كرة صالات دولية",
    "international gymnastics competitions": "منافسات جمباز دولية",
    "international handball competitions": "منافسات كرة يد دولية",
    "international ice hockey competitions": "منافسات هوكي جليد دولية",
    "international karate competitions": "منافسات كاراتيه دولية",
    "international kickboxing competitions": "منافسات كيك بوكسينغ دولية",
    "international netball players": "لاعبو كرة شبكة دوليون",
    "international roller hockey competitions": "منافسات هوكي دحرجة دولية",
    "international rugby league competitions": "منافسات دوري رجبي دولية",
    "international rugby union competitions": "منافسات اتحاد رجبي دولية",
    "international shooting competitions": "منافسات رماية دولية",
    "international softball competitions": "منافسات كرة لينة دولية",
    "international speed skating competitions": "منافسات تزلج سريع دولية",
    "international volleyball competitions": "منافسات كرة طائرة دولية",
    "international water polo competitions": "منافسات كرة ماء دولية",
    "international weightlifting competitions": "منافسات رفع أثقال دولية",
    "international wrestling competitions": "منافسات مصارعة دولية",
    "international youth basketball competitions": "منافسات كرة سلة شبابية دولية",
    "international youth football competitions": "منافسات كرة قدم شبابية دولية",
    "ju-jitsu world championships": "بطولة العالم للجوجوتسو",
    "men's hockey world cup": "كأس العالم للهوكي للرجال",
    "men's international basketball": "كرة سلة دولية للرجال",
    "men's international football": "كرة قدم دولية للرجال",
    "muay thai video games": "ألعاب فيديو موياي تاي",
    "multi-national basketball leagues": "دوريات كرة سلة متعددة الجنسيات",
    "national basketball team results": "نتائج منتخبات كرة سلة وطنية",
    "national cycling champions": "أبطال بطولات سباق دراجات هوائية وطنية",
    "national equestrian manager history": "تاريخ مدربو منتخبات فروسية وطنية",
    "national football team results": "نتائج منتخبات كرة قدم وطنية",
    "national ice hockey teams": "منتخبات هوكي جليد وطنية",
    "national junior football teams": "منتخبات كرة قدم وطنية للناشئين",
    "national junior men's handball teams": "منتخبات كرة يد وطنية للناشئين",
    "national lacrosse league": "دوريات لاكروس وطنية",
    "national men's equestrian manager history": "تاريخ مدربو منتخبات فروسية وطنية للرجال",
    "national rugby union premier leagues": "دوريات اتحاد رجبي وطنية من الدرجة الممتازة",
    "national rugby union teams": "منتخبات اتحاد رجبي وطنية",
    "national shooting championships": "بطولات رماية وطنية",
    "national squash teams": "منتخبات اسكواش وطنية",
    "national under-13 equestrian manager history": "تاريخ مدربو منتخبات فروسية تحت 13 سنة",
    "national under-14 equestrian manager history": "تاريخ مدربو منتخبات فروسية تحت 14 سنة",
    "national water polo teams": "منتخبات كرة ماء وطنية",
    "national women's equestrian manager history": "تاريخ مدربو منتخبات فروسية وطنية للسيدات",
    "netball world cup": "كأس العالم لكرة الشبكة",
    "outdoor equestrian": "فروسية في الهواء الطلق",
    "outdoor ice hockey": "هوكي جليد في الهواء الطلق",
    "premier lacrosse league": "دوريات لاكروس من الدرجة الممتازة",
    "professional football cups": "كؤوس كرة قدم للمحترفين",
    "professional ice hockey leagues": "دوريات هوكي جليد للمحترفين",
    "professional sports leagues": "دوريات رياضية للمحترفين",
    "roller hockey logos": "شعارات هوكي دحرجة",
    "rowing equipment": "معدات تجديف",
    "rugby league chairmen and investors": "رؤساء ومسيرو دوري رجبي",
    "rugby league world cup": "كأس العالم لدوري الرجبي",
    "shooting sports equipment": "معدات رماية",
    "snooker terminology": "مصطلحات سنوكر",
    "summer olympics football": "كرة القدم في الألعاب الأولمبية الصيفية",
    "summer olympics volleyball": "كرة الطائرة في الألعاب الأولمبية الصيفية",
    "summer olympics water polo": "كرة الماء في الألعاب الأولمبية الصيفية",
    "tennis logos": "شعارات كرة مضرب",
    "under-13 equestrian": "فروسية تحت 13 سنة",
    "under-14 equestrian": "فروسية تحت 14 سنة",
    "under-16 basketball": "كرة سلة تحت 16 سنة",
    "under-19 basketball": "كرة سلة تحت 19 سنة",
    "under-23 cycle racing": "سباق دراجات تحت 23 سنة",
    "water polo comics": "قصص مصورة كرة ماء",
    "water polo competition": "منافسات كرة ماء",
    "women's cricket world cup": "كأس العالم للكريكت للسيدات",
    "women's hockey world cup": "كأس العالم للهوكي للسيدات",
    "women's international football": "كرة قدم دولية للسيدات",
    "women's international futsal": "كرة صالات دولية للسيدات",
    "women's softball world cup": "كأس العالم للكرة اللينة للسيدات",
    "world athletics championships": "بطولة العالم لألعاب القوى",
    "world netball championship": "بطولة العالم لكرة الشبكة",
    "world netball championships": "بطولة العالم لكرة الشبكة",
    "world rowing championships medalists": "فائزون بميداليات بطولة العالم للتجديف",
    "world taekwondo championships": "بطولة العالم للتايكوندو",
    "wrestling world cup": "كأس العالم للمصارعة",
}


@pytest.mark.parametrize("category, expected_key", get_teams_new_data.items(), ids=get_teams_new_data.keys())
@pytest.mark.fast
def test_get_teams_new_data(category: str, expected_key: str) -> None:
    label = get_teams_new(category)
    assert label == expected_key


to_test = [
    ("test_get_teams_new_data", get_teams_new_data),
]


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, get_teams_new)
    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"


def test_get_teams_new() -> None:
    # Test with a basic input
    result = get_teams_new("football team")
    assert isinstance(result, str)

    result_empty = get_teams_new("")
    assert isinstance(result_empty, str)

    # Test with various inputs
    result_various = get_teams_new("basketball team")
    assert isinstance(result_various, str)



#!/usr/bin/python3
"""
Usage:
from .bot_lab import label_for_startwith_year_or_typeo

"""

import re

from ...fix import fixtitle
from ...format_bots.relation_mapping import translation_category_relations
from ...helps import logger
from ...new_resolvers.reslove_all import new_resolvers_all
from ...time_resolvers import time_to_arabic
from ...translations import Nat_mens
from ..ma_bots.country_bot import get_country
from ..make_bots.bot_2018 import get_pop_All_18
from .reg_result import get_cats, get_reg_result


def get_country_label(country_lower: str, country_not_lower: str, cate3: str, compare_lab: str) -> str:
    """Resolve a country label using population tables and fallbacks."""
    country_label = ""

    if country_lower:
        country_label = get_pop_All_18(country_lower, "")

        if not country_label:
            country_label = get_country(country_not_lower)

        if country_label == "" and cate3 == compare_lab:
            country_label = Nat_mens.get(country_lower, "")
            if country_label:
                country_label = country_label + " في"
                logger.info(f"a<<lightblue>>>2021 cnt_la == {country_label=}")

    return country_label


class LabelForStartWithYearOrTypeo:
    def __init__(self) -> None:
        """Set up placeholders used while constructing category labels."""
        self.cate = ""
        self.cate3 = ""
        self.year_at_first = ""
        self.In = ""
        self.country = ""
        self.country_lower = ""
        self.country_not_lower = ""
        self.cat_test = ""
        self.category_r = ""

        self.arlabel = ""
        self.suf = ""
        self.year_labe = ""

        self.country_label = ""
        self.Add_In = True
        self.Add_In_Done = False
        self.NoLab = False

    # ----------------------------------------------------
    # HELPERS
    # ----------------------------------------------------

    @staticmethod
    def replace_cat_test(cat_test: str, text: str) -> str:
        """Remove a substring from the category test helper in a case-insensitive way."""
        return cat_test.lower().replace(text.lower().strip(), "")

    # ----------------------------------------------------
    # 1 — PARSE
    # ----------------------------------------------------

    def parse_input(self, category_r: str) -> None:
        """Extract base components (year, type, country) from the category."""
        self.category_r = category_r

        self.cate, self.cate3 = get_cats(category_r)
        result = get_reg_result(category_r)

        self.year_at_first = result.year_at_first
        self.In = result.In
        self.country = result.country
        self.cat_test = result.cat_test

        self.country_lower = self.country.lower()
        self.country_not_lower = self.country

        logger.debug(f'>>>> {self.year_at_first=}, "{self.In=}, {self.country=}, {self.cat_test=}')

    # ----------------------------------------------------
    # 3 — HANDLE COUNTRY
    # ----------------------------------------------------

    def handle_country(self) -> None:
        """Look up and store the country label derived from the category."""
        if not self.country_lower:
            return

        cmp = self.year_at_first.strip() + " " + self.country_lower

        self.country_label = new_resolvers_all(self.country_lower) or get_country_label(
            self.country_lower, self.country_not_lower, self.cate3, cmp
        )

        if self.country_label:
            self.cat_test = self.replace_cat_test(self.cat_test, self.country_lower)
            logger.info(f"a<<lightblue>>> {self.country_label=}, {self.cate3=}")

    # ----------------------------------------------------
    # 4 — HANDLE YEAR
    # ----------------------------------------------------

    def handle_year(self) -> None:
        """Append year-based labels and mark prepositions when needed."""
        if not self.year_at_first:
            return

        self.year_labe = time_to_arabic.convert_time_to_arabic(self.year_at_first)

        if not self.year_labe:
            logger.info(f"No label for year_at_first({self.year_at_first}), {self.arlabel=}")
            return

        self.cat_test = self.replace_cat_test(self.cat_test, self.year_at_first)
        self.arlabel += " " + self.year_labe

        logger.info(
            f'252: year_at_first({self.year_at_first}) != "" arlabel:"{self.arlabel}",In.strip() == "{self.In.strip()}"'
        )

        if (self.In.strip() in ("in", "at")) and not self.suf.strip():
            logger.info(f"Add في to arlabel:in, at: {self.arlabel}")

            self.arlabel += " في "
            self.cat_test = self.replace_cat_test(self.cat_test, self.In)
            self.Add_In = False
            self.Add_In_Done = True

    # ----------------------------------------------------
    # 5 — RELATION MAPPING
    # ----------------------------------------------------

    def handle_relation_mapping(self) -> None:
        """Remove relation keywords that have already influenced the label."""
        if not self.In.strip():
            return

        if self.In.strip() in translation_category_relations:
            if translation_category_relations[self.In.strip()].strip() in self.arlabel:
                self.cat_test = self.replace_cat_test(self.cat_test, self.In)
        else:
            self.cat_test = self.replace_cat_test(self.cat_test, self.In)

        self.cat_test = re.sub(r"category:", "", self.cat_test)

        logger.debug(f'<<lightblue>>>>>> cat_test: "{self.cat_test}" ')

    # ----------------------------------------------------
    # 6 — APPLY LABEL RULES
    # ----------------------------------------------------

    def apply_label_rules(self) -> None:
        """Apply validation rules and build labels using available data."""

        if self.year_at_first and not self.year_labe:
            self.NoLab = True
            logger.info('year_labe = ""')
            return

        if (not self.year_at_first or not self.year_labe) and self.cat_test.strip():
            self.NoLab = True
            logger.info('year_at_first ==  or year_labe == ""')
            return

        if not self.country_lower and not self.In:
            logger.info('a<<lightblue>>>>>> country_lower == "" and In ==  "" ')
            if self.suf:
                self.arlabel = self.arlabel + " " + self.suf
            self.arlabel = re.sub(r"\s+", " ", self.arlabel)
            logger.debug("a<<lightblue>>>>>> No country_lower.")
            return

        logger.info(f"a<<lightblue>>>>>> No label., {self.country_lower=}")
        self.NoLab = True

    # ----------------------------------------------------
    # 8 — FINALIZE
    # ----------------------------------------------------

    def finalize(self) -> str:
        """Perform final validation and return the completed label."""
        if not self.arlabel:
            return ""

        category2 = (
            self.cate[len("category:") :].lower() if self.cate.lower().startswith("category:") else self.cate.lower()
        )

        if not self.cat_test.strip():
            logger.debug("<<lightgreen>>>>>> arlabel " + self.arlabel)

        elif self.cat_test == self.country_lower or self.cat_test == ("in " + self.country_lower):
            logger.debug("<<lightgreen>>>>>> cat_test False.. ")
            logger.debug(f"<<lightblue>>>>>> cat_test = {self.country_lower=} ")
            self.NoLab = True

        elif self.cat_test.lower() == category2.lower():
            logger.debug("<<lightblue>>>>>> cat_test = category2 ")

        else:
            logger.debug("<<lightgreen>>>> >> cat_test False result.. ")
            logger.debug(f" {self.cat_test=} ")
            logger.debug("<<lightgreen>>>>>> arlabel " + self.arlabel)
            self.NoLab = True

        logger.debug("<<lightgreen>>>>>> arlabel " + self.arlabel)

        if not self.NoLab:
            if re.sub("[abcdefghijklmnopqrstuvwxyz]", "", self.arlabel, flags=re.IGNORECASE) == self.arlabel:
                self.arlabel = fixtitle.fixlabel(self.arlabel, en=self.category_r)

                logger.info(f"a<<lightred>>>>>> arlabel ppoi:{self.arlabel}")
                logger.info(f'>>>> <<lightyellow>> cat:"{self.category_r}", category_lab "{self.arlabel}"')
                logger.info("<<lightblue>>>> ^^^^^^^^^ event2 end 3 ^^^^^^^^^ ")

                return self.arlabel

        return ""

    # ----------------------------------------------------
    # MASTER FUNCTION
    # ----------------------------------------------------

    def build(self, category_r: str) -> str:
        """Construct the final label for categories starting with a year or type."""
        self.parse_input(category_r)

        if not self.year_at_first:
            return ""

        self.handle_country()
        self.handle_year()
        self.handle_relation_mapping()
        self.apply_label_rules()

        return self.finalize()


def label_for_startwith_year_or_typeo(category_r: str) -> str:
    """Return an Arabic label for categories that begin with years or types."""
    builder = LabelForStartWithYearOrTypeo()

    result = ""
    result = builder.build(category_r).strip()
    logger.debug(f":: label_for_startwith_year_or_typeo: {category_r=} => {result=}")
    return result



#!/usr/bin/python3
"""Integration tests for v3i translations resolvers validating country, year, and combined formatters."""

import pytest
from load_one_data import dump_diff, dump_diff_text, one_dump_test

from ArWikiCats import resolve_label_ar
from ArWikiCats.new_resolvers.translations_resolvers_v3i.resolve_v3i import resolve_year_job_from_countries

test_deaths_data = {
    "16th-century deaths from tuberculosis": "وفيات بسبب السل في القرن 16",
    "20th-century deaths from infectious disease": "وفيات بسبب أمراض معدية في القرن 20",
    "17th-century deaths from tuberculosis": "وفيات بسبب السل في القرن 17",
    "18th-century deaths from tuberculosis": "وفيات بسبب السل في القرن 18",
    "19th-century deaths from tuberculosis": "وفيات بسبب السل في القرن 19",
    "20th-century deaths from tuberculosis": "وفيات بسبب السل في القرن 20",
    "7th-century deaths from tuberculosis": "وفيات بسبب السل في القرن 7",
    "21st-century deaths from tuberculosis": "وفيات بسبب السل في القرن 21",
    "14th-century deaths from tuberculosis": "وفيات بسبب السل في القرن 14",
}

test_females_data = {
    "18th-century businesswomen from the Russian Empire": "سيدات أعمال من الإمبراطورية الروسية في القرن 18",
    "18th-century actresses from Bohemia": "ممثلات من بوهيميا في القرن 18",
    "18th-century actresses from the Holy Roman Empire": "ممثلات من الإمبراطورية الرومانية المقدسة في القرن 18",
    "19th-century actresses from the Ottoman Empire": "ممثلات من الدولة العثمانية في القرن 19",
    "19th-century actresses from the Russian Empire": "ممثلات من الإمبراطورية الروسية في القرن 19",
    "19th-century businesswomen from the Russian Empire": "سيدات أعمال من الإمبراطورية الروسية في القرن 19",
    "20th-century actresses from Georgia (country)": "ممثلات من جورجيا في القرن 20",
    "20th-century actresses from Northern Ireland": "ممثلات من أيرلندا الشمالية في القرن 20",
    "20th-century actresses from the Ottoman Empire": "ممثلات من الدولة العثمانية في القرن 20",
    "21st-century actresses from Georgia (country)": "ممثلات من جورجيا في القرن 21",
    "21st-century actresses from Northern Ireland": "ممثلات من أيرلندا الشمالية في القرن 21",
}

test_data_standard = {
    "10th-century historians from al-Andalus": "مؤرخون من الأندلس في القرن 10",
    "10th-century historians from the Abbasid Caliphate": "مؤرخون من الدولة العباسية في القرن 10",
    "11th-century historians from al-Andalus": "مؤرخون من الأندلس في القرن 11",
    "11th-century people from the Kingdom of Aragon": "أشخاص من مملكة أرغون في القرن 11",
    "12th-century historians from al-Andalus": "مؤرخون من الأندلس في القرن 12",
    "13th-century clergy from the Holy Roman Empire": "رجال دين من الإمبراطورية الرومانية المقدسة في القرن 13",
    "13th-century historians from al-Andalus": "مؤرخون من الأندلس في القرن 13",
    "13th-century people from the crown of aragon": "أشخاص من تاج أرغون في القرن 13",
    "14th-century historians from al-Andalus": "مؤرخون من الأندلس في القرن 14",
    "15th-century artists from the Ottoman Empire": "فنانون من الدولة العثمانية في القرن 15",
    "15th-century astronomers from the Holy Roman Empire": "فلكيون من الإمبراطورية الرومانية المقدسة في القرن 15",
    "15th-century people from the Crown of Aragon": "أشخاص من تاج أرغون في القرن 15",
    "16th-century artists from the Ottoman Empire": "فنانون من الدولة العثمانية في القرن 16",
    "16th-century astronomers from the Holy Roman Empire": "فلكيون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century astronomers from the Ottoman Empire": "فلكيون من الدولة العثمانية في القرن 16",
    "16th-century botanists from the Holy Roman Empire": "علماء نباتات من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century businesspeople from the Ottoman Empire": "شخصيات أعمال من الدولة العثمانية في القرن 16",
    "16th-century clergy from the Holy Roman Empire": "رجال دين من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century composers from the Holy Roman Empire": "ملحنون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century historians from Bohemia": "مؤرخون من بوهيميا في القرن 16",
    "17th-century architects from the Holy Roman Empire": "معماريون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century artists from the Ottoman Empire": "فنانون من الدولة العثمانية في القرن 17",
    "17th-century astronomers from the Holy Roman Empire": "فلكيون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century astronomers from the Ottoman Empire": "فلكيون من الدولة العثمانية في القرن 17",
    "17th-century botanists from the Holy Roman Empire": "علماء نباتات من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century businesspeople from the Holy Roman Empire": "شخصيات أعمال من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century businesspeople from the Ottoman Empire": "شخصيات أعمال من الدولة العثمانية في القرن 17",
    "17th-century civil servants from the Ottoman Empire": "موظفو خدمة مدنية من الدولة العثمانية في القرن 17",
    "17th-century clergy from the Holy Roman Empire": "رجال دين من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century composers from the Holy Roman Empire": "ملحنون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century engineers from the Holy Roman Empire": "مهندسون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century engravers from the Holy Roman Empire": "نقاشون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century historians from Bohemia": "مؤرخون من بوهيميا في القرن 17",
    "17th-century sculptors from the Holy Roman Empire": "نحاتون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "18th-century actors from Bohemia": "ممثلون من بوهيميا في القرن 18",
    "18th-century architects from the Holy Roman Empire": "معماريون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century architects from the Russian Empire": "معماريون من الإمبراطورية الروسية في القرن 18",
    "18th-century artists from the Holy Roman Empire": "فنانون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century artists from the Ottoman Empire": "فنانون من الدولة العثمانية في القرن 18",
    "18th-century artists from the Republic of Geneva": "فنانون من جمهورية جنيف في القرن 18",
    "18th-century artists from the Russian Empire": "فنانون من الإمبراطورية الروسية في القرن 18",
    "18th-century astronomers from the Holy Roman Empire": "فلكيون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century ballet dancers from Bohemia": "راقصو باليه من بوهيميا في القرن 18",
    "18th-century botanists from the Holy Roman Empire": "علماء نباتات من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century botanists from the Russian Empire": "علماء نباتات من الإمبراطورية الروسية في القرن 18",
    "18th-century businesspeople from the Holy Roman Empire": "شخصيات أعمال من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century businesspeople from the Russian Empire": "شخصيات أعمال من الإمبراطورية الروسية في القرن 18",
    "18th-century chemists from the Holy Roman Empire": "كيميائيون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century classical composers from Bohemia": "ملحنون كلاسيكيون من بوهيميا في القرن 18",
    "18th-century classical composers from the Holy Roman Empire": "ملحنون كلاسيكيون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century clergy from the Holy Roman Empire": "رجال دين من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century composers from the Holy Roman Empire": "ملحنون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century engineers from the Holy Roman Empire": "مهندسون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century engravers from the Holy Roman Empire": "نقاشون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century women from the Russian Empire": "نساء من الإمبراطورية الروسية في القرن 18",
    "19th-century architects from the Russian Empire": "معماريون من الإمبراطورية الروسية في القرن 19",
    "19th-century artists from the Ottoman Empire": "فنانون من الدولة العثمانية في القرن 19",
    "19th-century artists from the Russian Empire": "فنانون من الإمبراطورية الروسية في القرن 19",
    "19th-century astronomers from the Russian Empire": "فلكيون من الإمبراطورية الروسية في القرن 19",
    "19th-century ballet dancers from the Russian Empire": "راقصو باليه من الإمبراطورية الروسية في القرن 19",
    "19th-century biologists from the Russian Empire": "علماء أحياء من الإمبراطورية الروسية في القرن 19",
    "19th-century botanists from the Russian Empire": "علماء نباتات من الإمبراطورية الروسية في القرن 19",
    "19th-century businesspeople from the Ottoman Empire": "شخصيات أعمال من الدولة العثمانية في القرن 19",
    "19th-century businesspeople from the Russian Empire": "شخصيات أعمال من الإمبراطورية الروسية في القرن 19",
    "19th-century classical composers from the Russian Empire": "ملحنون كلاسيكيون من الإمبراطورية الروسية في القرن 19",
    "19th-century women from Georgia (country)": "نساء من جورجيا في القرن 19",
    "19th-century women from Ottoman Arabia": "نساء من الدولة العثمانية في شبه الجزيرة العربية في القرن 19",
    "19th-century women from the Ottoman Empire": "نساء من الدولة العثمانية في القرن 19",
    "19th-century women from the Russian Empire": "نساء من الإمبراطورية الروسية في القرن 19",
    "20th-century actors from Georgia (country)": "ممثلون من جورجيا في القرن 20",
    "20th-century artists from Georgia (country)": "فنانون من جورجيا في القرن 20",
    "20th-century artists from the Ottoman Empire": "فنانون من الدولة العثمانية في القرن 20",
    "20th-century civil servants from the Ottoman Empire": "موظفو خدمة مدنية من الدولة العثمانية في القرن 20",
    "20th-century classical composers from Northern Ireland": "ملحنون كلاسيكيون من أيرلندا الشمالية في القرن 20",
    "20th-century dramatists and playwrights from Georgia (country)": "كتاب دراما ومسرح من جورجيا في القرن 20",
    "20th-century people from insular areas of the United States": "أشخاص من المناطق المعزولة في الولايات المتحدة في القرن 20",
    "20th-century politicians from insular areas of the United States": "سياسيون من المناطق المعزولة في الولايات المتحدة في القرن 20",
    "20th-century women from Georgia (country)": "نساء من جورجيا في القرن 20",
    "20th-century women from Northern Ireland": "نساء من أيرلندا الشمالية في القرن 20",
    "20th-century women from the Ottoman Empire": "نساء من الدولة العثمانية في القرن 20",
    "20th-century women politicians from insular areas of the United States": "سياسيات من المناطق المعزولة في الولايات المتحدة في القرن 20",
    "21st-century artists from Georgia (country)": "فنانون من جورجيا في القرن 21",
    "21st-century classical composers from Northern Ireland": "ملحنون كلاسيكيون من أيرلندا الشمالية في القرن 21",
    "21st-century dramatists and playwrights from Georgia (country)": "كتاب دراما ومسرح من جورجيا في القرن 21",
    "21st-century people from insular areas of the United States": "أشخاص من المناطق المعزولة في الولايات المتحدة في القرن 21",
    "21st-century politicians from insular areas of the United States": "سياسيون من المناطق المعزولة في الولايات المتحدة في القرن 21",
    "21st-century women from Georgia (country)": "نساء من جورجيا في القرن 21",
    "21st-century women from Northern Ireland": "نساء من أيرلندا الشمالية في القرن 21",
    "21st-century women politicians from insular areas of the United States": "سياسيات من المناطق المعزولة في الولايات المتحدة في القرن 21",
    "8th-century women from the Abbasid Caliphate": "نساء من الدولة العباسية في القرن 8",
    "9th-century women from the Abbasid Caliphate": "نساء من الدولة العباسية في القرن 9",
}


@pytest.mark.parametrize("category,expected", test_data_standard.items(), ids=test_data_standard.keys())
@pytest.mark.fast
def test_resolve_v3i_more_1(category: str, expected: str) -> None:
    """Test resolve year job from countries function for test_data_standard."""
    result1 = resolve_year_job_from_countries(category)
    assert result1 == expected

    result2 = resolve_label_ar(category)
    assert result2 == expected


@pytest.mark.parametrize("category,expected", test_females_data.items(), ids=test_females_data.keys())
@pytest.mark.fast
def test_females_data_1(category: str, expected: str) -> None:
    """Test resolve year job from countries function for test_females_data."""
    result2 = resolve_label_ar(category)
    assert result2 == expected

    result1 = resolve_year_job_from_countries(category)
    assert result1 == expected


to_test = [
    ("test_resolve_v3i_more_2", test_data_standard, resolve_year_job_from_countries),
    ("test_females_data_1", test_females_data, resolve_year_job_from_countries),
]


@pytest.mark.parametrize("name,data,callback", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    # dump_diff_text(expected, diff_result, name)

    # same_data = {x: v for x, v in data.items() if x not in diff_result}
    # dump_diff(same_data, f"{name}_same")
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""
Tests
"""

import pytest

from ArWikiCats.new.end_start_bots.fax2_episodes import get_episodes

data = [
    ("2016 American television episodes", "2016 American television", "حلقات {}"),
    ("Game of Thrones (season 1) episodes", "Game of Thrones", "حلقات {} الموسم 1"),
    ("Game of Thrones season 2 episodes", "Game of Thrones", "حلقات {} الموسم 2"),
    ("", "", "حلقات {}"),
]

# --- 1. Basic known test cases ---


@pytest.mark.parametrize(
    "text, expected_cat, expected_label",
    data,
    ids=[x[0] for x in data],
)
@pytest.mark.fast
def test_basic_cases(text: str, expected_cat: str, expected_label: str) -> None:
    list_of_cat, category3 = get_episodes(text)
    assert list_of_cat == expected_label
    assert category3 == expected_cat


# --- 2. Test all seasons (1 – 10) for both key patterns ---
@pytest.mark.fast
@pytest.mark.parametrize("i", range(1, 11))
def test_all_seasons_parentheses(i) -> None:
    text = f"My Show (season {i}) episodes"
    list_of_cat, category3 = get_episodes(text)
    assert list_of_cat == f"حلقات {{}} الموسم {i}"
    assert category3 == "My Show"


@pytest.mark.fast
@pytest.mark.parametrize("i", range(1, 11))
def test_all_seasons_no_parentheses(i) -> None:
    text = f"My Show season {i} episodes"
    list_of_cat, category3 = get_episodes(text)
    assert list_of_cat == f"حلقات {{}} الموسم {i}"
    assert category3 == "My Show"


# --- 3. Case-insensitive handling ---
@pytest.mark.fast
def test_case_insensitive() -> None:
    text = "My Show Season 3 Episodes"
    list_of_cat, category3 = get_episodes(text)
    assert list_of_cat == "حلقات {} الموسم 3"
    assert category3 == "My Show"


# --- 4. Ensure extra spaces trimmed properly ---
@pytest.mark.fast
def test_trailing_spaces() -> None:
    text = "My Show season 4 episodes    "
    list_of_cat, category3 = get_episodes(text)
    assert category3 == "My Show"


# --- 5. When `category3_nolower` is provided ---
@pytest.mark.fast
def test_override_category3_nolower() -> None:
    text = "abc season 5 episodes"
    nolower = "XYZ season 5 episodes"
    list_of_cat, category3 = get_episodes(text, nolower)
    assert list_of_cat == "حلقات {} الموسم 5"
    assert category3 == "XYZ"  # must follow nolower


# --- 6. Default fallback when no season pattern is matched ---
@pytest.mark.fast
def test_fallback_no_season() -> None:
    text = "Random episodes"
    list_of_cat, category3 = get_episodes(text)
    assert list_of_cat == "حلقات {}"
    assert category3 == "Random"


# --- 7. Ensure only end is removed, not middle ---
@pytest.mark.fast
def test_does_not_trim_middle_text() -> None:
    text = "Show episodes special"
    list_of_cat, category3 = get_episodes(text)
    assert list_of_cat == "حلقات {}"
    assert category3 == "Show episodes special"  # no trimming because does NOT end with episodes


# --- 8. Ensure correct slicing removal of 'episodes' ---
@pytest.mark.fast
def test_exact_slice_removal() -> None:
    text = "My Series episodes"
    list_of_cat, category3 = get_episodes(text)
    assert category3 == "My Series"


# --- 9. Protect against strings shorter than 'episodes' ---
@pytest.mark.fast
def test_short_string() -> None:
    text = "episodes"
    list_of_cat, category3 = get_episodes(text)
    assert category3 == ""


# --- 10. Weird inputs / robustness ---
@pytest.mark.fast
@pytest.mark.parametrize("text", ["   episodes", "EPISODES", " Episodes"])
def test_weird_inputs(text) -> None:
    list_of_cat, category3 = get_episodes(text)
    assert list_of_cat == "حلقات {}"
    assert isinstance(category3, str)



#!/usr/bin/python3
"""
Sports team and club category processing.
"""

import functools

from ..helps import logger
from ..new.resolve_films_bots import get_films_key_tyty_new, get_films_key_tyty_new_and_time
from ..new.resolve_films_bots.film_keys_bot import Films
from ..new_resolvers.relations_resolver import new_relations_resolvers
from ..translations import INTER_FEDS_LOWER, Clubs_key_2, pop_of_football_lower
from .o_bots.utils import resolve_suffix_template

Teams_new_end_keys = {
    "broadcasters": "مذيعو {}",
    "commentators": "معلقو {}",
    "commissioners": "مفوضو {}",
    "trainers": "مدربو {}",
    "chairmen and investors": "رؤساء ومسيرو {}",
    "coaches": "مدربو {}",
    "managers": "مدربو {}",  # "مدراء {}"
    "manager": "مدربو {}",
    "manager history": "تاريخ مدربو {}",
    "footballers": "لاعبو {}",
    "playerss": "لاعبو {}",
    "players": "لاعبو {}",
    "fan clubs": "أندية معجبي {}",
    "owners and executives": "رؤساء تنفيذيون وملاك {}",
    "personnel": "أفراد {}",
    "owners": "ملاك {}",
    "executives": "مدراء {}",
    "equipment": "معدات {}",
    "culture": "ثقافة {}",
    "logos": "شعارات {}",
    "tactics and skills": "مهارات {}",
    "media": "إعلام {}",
    "people": "أعلام {}",
    "terminology": "مصطلحات {}",
    # "religious occupations": "مهن دينية {}",
    # "occupations": "مهن {}",
    "variants": "أشكال {}",
    "governing bodies": "هيئات تنظيم {}",
    "bodies": "هيئات {}",
    "video games": "ألعاب فيديو {}",
    "comics": "قصص مصورة {}",
    "cups": "كؤوس {}",
    "records and statistics": "سجلات وإحصائيات {}",
    "leagues": "دوريات {}",
    "leagues seasons": "مواسم دوريات {}",
    "seasons": "مواسم {}",
    "competition": "منافسات {}",
    "competitions": "منافسات {}",
    "world competitions": "منافسات {} عالمية",
    "teams": "فرق {}",
    "television series": "مسلسلات تلفزيونية {}",
    "films": "أفلام {}",
    "championships": "بطولات {}",
    "music": "موسيقى {}",
    "clubs and teams": "أندية وفرق {}",
    "clubs": "أندية {}",
    "referees": "حكام {}",
    "organizations": "منظمات {}",
    "non-profit organizations": "منظمات غير ربحية {}",
    "non-profit publishers": "ناشرون غير ربحيون {}",
    "stadiums": "ملاعب {}",
    "lists": "قوائم {}",
    "awards": "جوائز {}",
    "songs": "أغاني {}",
    "non-playing staff": "طاقم {} غير اللاعبين",
    "umpires": "حكام {}",
    "cup playoffs": "تصفيات كأس {}",
    "cup": "كأس {}",
    "results": "نتائج {}",
    "matches": "مباريات {}",
    "rivalries": "دربيات {}",
    "champions": "أبطال {}",
}

# sorted by len of " " in key
Teams_new_end_keys = dict(
    sorted(
        Teams_new_end_keys.items(),
        key=lambda k: (-k[0].count(" "), -len(k[0])),
    )
)


def _resolve_club_label(club_key: str) -> str:
    """
    Resolve the Arabic label for a club key by checking configured lookup sources.

    Parameters:
        club_key (str): Key identifying the club or entity to resolve.

    Returns:
        str: The resolved Arabic label for the given club_key, or an empty string if no match is found.
    """
    club_lab = (
        Clubs_key_2.get(club_key)
        or Clubs_key_2.get(club_key.lower())
        or pop_of_football_lower.get(club_key)
        or INTER_FEDS_LOWER.get(club_key)
        or new_relations_resolvers(club_key)
        or get_films_key_tyty_new_and_time(club_key)
        or get_films_key_tyty_new(club_key)
        or Films(club_key)
        or ""
    )
    return club_lab


@functools.lru_cache(maxsize=None)
def Get_team_work_Club(category: str) -> str:
    """Return the Arabic label for ``category`` using known suffixes.

    Args:
        category: The category name to resolve.

    Returns:
        The resolved Arabic label or an empty string if the suffix is unknown.
    """

    normalized = category.strip()
    logger.debug(f"get_parties_lab {category=}")

    category_label = resolve_suffix_template(normalized, Teams_new_end_keys, _resolve_club_label)

    if category_label:
        logger.info(f"get_parties_lab {category=}, {category_label=}")

    return category_label


__all__ = [
    "Teams_new_end_keys",
    "Get_team_work_Club",
]



#!/usr/bin/python3
"""
Module for film category translation formatting with double-key support.

This module provides the `format_films_country_data` factory function for
creating MultiDataFormatterDataDouble instances. It's designed for translating
film-related categories that contain both nationality and genre elements,
where the genre can have two adjacent keys (e.g., "action drama films").

Example:
    >>> from ArWikiCats.translations_formats import format_films_country_data
    >>> formatted_data = {"{nat_en} {film_key} films": "أفلام {film_ar} {nat_ar}"}
    >>> data_list = {"british": "بريطانية", "american": "أمريكية"}
    >>> data_list2 = {"action": "أكشن", "drama": "دراما", "comedy": "كوميدي"}
    >>> bot = format_films_country_data(
    ...     formatted_data=formatted_data,
    ...     data_list=data_list,
    ...     data_list2=data_list2,
    ... )
    >>> bot.search("british action drama films")
    'أفلام أكشن دراما بريطانية'
"""

from typing import Dict

from .DataModel import FormatData
from .DataModelDouble import FormatDataDouble, MultiDataFormatterDataDouble


def format_films_country_data(
    formatted_data: Dict[str, str],
    data_list: Dict[str, str],
    key_placeholder: str = "{nat_en}",
    value_placeholder: str = "{nat_ar}",
    data_list2: Dict[str, str] = {},
    other_formatted_data: Dict[str, str] = {},
    key2_placeholder: str = "{film_key}",
    value2_placeholder: str = "{film_ar}",
    text_after: str = "",
    text_before: str = "",
    data_to_find: Dict[str, str] | None = None,
) -> MultiDataFormatterDataDouble:
    """
    Create a MultiDataFormatterDataDouble for film category translations.

    This factory function creates a formatter that handles film categories
    with nationality and genre elements. The genre element supports double-key
    matching (e.g., "action drama" as two adjacent genre keys).

    Args:
        formatted_data: Template patterns mapping English patterns to Arabic templates.
            Keys should contain placeholders like "{nat_en}" and "{film_key}".
        data_list: Nationality key-to-Arabic-label mappings (e.g., {"british": "بريطانية"}).
        key_placeholder: Placeholder for nationality key in templates. Default: "{nat_en}".
        value_placeholder: Placeholder for nationality value in Arabic templates. Default: "{nat_ar}".
        data_list2: Genre key-to-Arabic-label mappings (e.g., {"action": "أكشن"}).
        other_formatted_data: Additional template patterns for genre-only translations.
        key2_placeholder: Placeholder for genre key in templates. Default: "{film_key}".
        value2_placeholder: Placeholder for genre value in Arabic templates. Default: "{film_ar}".
        text_after: Optional text that appears after the nationality key.
        text_before: Optional text that appears before the nationality key.
        data_to_find: Optional direct lookup dictionary for category labels.

    Returns:
        MultiDataFormatterDataDouble: A configured formatter for film category translations.

    Example:
        >>> formatted_data = {"{nat_en} {film_key} films": "أفلام {film_ar} {nat_ar}"}
        >>> data_list = {"british": "بريطانية"}
        >>> data_list2 = {"action": "أكشن", "drama": "دراما"}
        >>> bot = format_films_country_data(
        ...     formatted_data=formatted_data,
        ...     data_list=data_list,
        ...     data_list2=data_list2,
        ... )
        >>> bot.search("british action films")
        'أفلام أكشن بريطانية'
    """

    # Country bot (FormatData)
    country_bot = FormatData(
        formatted_data=formatted_data,
        data_list=data_list,
        key_placeholder=key_placeholder,
        value_placeholder=value_placeholder,
        text_after=text_after,
        text_before=text_before,
    )

    other_bot = FormatDataDouble(
        formatted_data=other_formatted_data,  # to use from search_all
        data_list=data_list2,
        key_placeholder=key2_placeholder,
        value_placeholder=value2_placeholder,
    )

    return MultiDataFormatterDataDouble(
        country_bot=country_bot,
        other_bot=other_bot,
        data_to_find=data_to_find,
    )


__all__ = [
    "format_films_country_data",
]



"""
Tests
"""

import pytest

from ArWikiCats.legacy_bots.ma_bots2.lab import get_type_country

data = [
    ("1450s disestablishments in arizona territory", "in", ("1450s disestablishments ", " arizona territory")),
]


@pytest.mark.parametrize("category, separator, output", data, ids=[x[0] for x in data])
@pytest.mark.fast
def test_get_type_country_data(category: str, separator: str, output: str) -> None:
    label = get_type_country(category, separator)
    assert label == output



"""Utilities for normalizing year placement within Arabic labels."""

from __future__ import annotations

import functools
import re

from ..helps import dump_data, logger
from ..legacy_bots.make_bots.reg_lines import YEARS_REGEX_AR

# Precompiled Regex Patterns
REGEX_WHITESPACE = re.compile(r"\s+", re.IGNORECASE)
REGEX_QM = re.compile(r"\bق\.م\b", re.IGNORECASE)

REGEX_YEAR_IN_SECOND_PART = re.compile(r"^(?P<subject>.*)\sحسب\s(?P<by>[\s\w]+)$", re.IGNORECASE)

REGEX_BY_DATE_PATTERN = re.compile(
    rf"^(?P<first_part>.*)\sحسب\s(?P<by_part>[\s\w]+)\sفي\s(?P<date>{YEARS_REGEX_AR})$", re.IGNORECASE
)
REGEX_YEAR_FIRST_PATTERN = re.compile(
    rf"^(?P<first_part>{YEARS_REGEX_AR})\sفي\s(?P<second_part>[^0-9]*)$", re.IGNORECASE
)


# @dump_data(1, compare_with_output="text_str")
def move_by_in(text_str: str) -> str:
    """
    A function that takes in a string and searches for a specific pattern within it. The function replaces underscores in the string with spaces and then uses a regular expression to search for a pattern of the form '{first_part} حسب {by_part} في {date}'.

    Parameters:
    - text_str (str): The input string.

    Returns:
    - str: The modified string if a match is found, otherwise the original string.
    """
    # تصنيف:اتحاد الرجبي حسب البلد في 1989
    text_normalized = text_str.replace("_", " ")
    new_text = text_normalized
    result = REGEX_BY_DATE_PATTERN.search(text_normalized)

    if not result:
        logger.debug(f"move_by_in: no match for {text_str}")
        return text_str

    # [[تصنيف:اتحاد الرجبي في 1989 حسب البلد]]
    first_part = result.group("first_part")
    by_part = result.group("by_part")
    date = result.group("date")
    new_text = f"{first_part} في {date} حسب {by_part}"
    logger.debug(f"move_by_in: {new_text=}")

    new_text = REGEX_WHITESPACE.sub(" ", new_text)
    new_text = REGEX_QM.sub("ق م", new_text)
    new_text = new_text.replace(" في في ", " في ")

    return new_text


# @dump_data(1, compare_with_output="text_str")
def move_years_first(text_str: str) -> str:
    """Move leading year fragments to the end of the label when applicable.

    Args:
        text_str: Raw label text.

    Returns:
        A normalized string with the year moved after the subject.
    """
    # return text_str
    new_text = text_str
    match = REGEX_YEAR_FIRST_PATTERN.match(text_str)

    if not match:
        logger.debug(f'move_years_first: no match for "{text_str}"')
        return text_str

    first_part = match.group("first_part").strip()
    second_part = match.group("second_part").strip()
    logger.debug(f"move_years_first: first_part={first_part} second_part={second_part}")
    skip_it = [
        "أفلام",
        "الأفلام",
    ]
    if second_part in skip_it:
        return text_str
    if " في x" in second_part:
        logger.debug("move_years_first: skipping due to nested preposition")
        return text_str

    new_text = f"{second_part} في {first_part}"
    if result := REGEX_YEAR_IN_SECOND_PART.search(second_part):
        logger.debug("move_years_first: found حسب clause")
        subject = result.group("subject")
        by_part = result.group("by")
        new_text = f"{subject} في {first_part} حسب {by_part}"

    new_text = REGEX_WHITESPACE.sub(" ", new_text)
    new_text = REGEX_QM.sub("ق م", new_text)
    new_text = new_text.replace(" في في ", " في ")
    return new_text


@functools.lru_cache(maxsize=10000)
def move_years(text_str: str) -> str:
    """Normalize the placement of year fragments within the label.

    Args:
        text_str: Raw label text.

    Returns:
        The normalized label with category namespace preserved.
    """

    text_str = text_str.replace("_", " ").strip()
    is_category_namespace = text_str.startswith("تصنيف:")

    if is_category_namespace:
        text_str = text_str.replace("تصنيف:", "")

    new_text = move_years_first(text_str)
    if new_text == text_str:
        new_text = move_by_in(text_str)

    if is_category_namespace:
        new_text = f"تصنيف:{new_text}"

    return new_text


__all__ = [
    "move_by_in",
    "move_years",
    "move_years_first",
]



import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.sports_resolvers.sport_lab_nat import sport_lab_nat_load_new

data_0 = {
    "central american reserve football teams": "فرق كرة قدم أمريكية أوسطية احتياطية",
    "american defunct football teams": "فرق كرة قدم أمريكية سابقة",
    "central american national football teams": "منتخبات كرة قدم وطنية أمريكية أوسطية",
    "south american national rugby union teams": "منتخبات اتحاد رجبي وطنية أمريكية جنوبية",
    "oceanian national rugby union teams": "منتخبات اتحاد رجبي وطنية أوقيانوسية",
    "oceanian national football teams": "منتخبات كرة قدم وطنية أوقيانوسية",
    "european national beach soccer teams": "منتخبات كرة قدم شاطئية وطنية أوروبية",
    "luxembourg national football teams": "منتخبات كرة قدم وطنية لوكسمبورغية",
    "central american national rugby union teams": "منتخبات اتحاد رجبي وطنية أمريكية أوسطية",
}

data_1 = {
    "central american under-13 football": "كرة قدم أمريكية أوسطية تحت 13 سنة",
    "central american football": "كرة قدم أمريكية أوسطية",
    "central american national football": "كرة قدم وطنية أمريكية أوسطية",
    "african national under-23 football teams": "منتخبات كرة قدم وطنية إفريقية تحت 23 سنة",
    "south american national under-15 football teams": "منتخبات كرة قدم وطنية أمريكية جنوبية تحت 15 سنة",
    "republic-of ireland national youth football teams": "منتخبات كرة قدم وطنية أيرلندية للشباب",
    "oceanian national under-17 football teams": "منتخبات كرة قدم وطنية أوقيانوسية تحت 17 سنة",
    "botswana national youth football teams": "منتخبات كرة قدم وطنية بوتسوانية للشباب",
    "asian national under-23 football teams": "منتخبات كرة قدم وطنية آسيوية تحت 23 سنة",
    "asian national youth football teams": "منتخبات كرة قدم وطنية آسيوية للشباب",
    "european national women's volleyball teams": "منتخبات كرة طائرة وطنية أوروبية للسيدات",
    "european national women's under-21 football teams": "منتخبات كرة قدم وطنية أوروبية تحت 21 سنة للسيدات",
    "afghan cricket": "كريكت أفغانية",
    "african archery": "نبالة إفريقية",
    "african basketball leagues": "دوريات كرة سلة إفريقية",
    "african basketball": "كرة سلة إفريقية",
    "african football leagues": "دوريات كرة قدم إفريقية",
    "african handball": "كرة يد إفريقية",
    "albanian football leagues": "دوريات كرة قدم ألبانية",
    "algerian basketball": "كرة سلة جزائرية",
    "american basketball": "كرة سلة أمريكية",
    "american college": "كليات أمريكية",
    "american ice hockey": "هوكي جليد أمريكية",
    "american soccer leagues": "دوريات كرة قدم أمريكية",
    "andorran football leagues": "دوريات كرة قدم أندورية",
    "angolan basketball": "كرة سلة أنغولية",
    "argentine basketball": "كرة سلة أرجنتينية",
    "argentine football leagues": "دوريات كرة قدم أرجنتينية",
    "armenian football leagues": "دوريات كرة قدم أرمينية",
    "asian basketball leagues": "دوريات كرة سلة آسيوية",
    "asian basketball": "كرة سلة آسيوية",
    "asian domestic cricket competitions": "منافسات كريكت آسيوية محلية",
    "asian football leagues": "دوريات كرة قدم آسيوية",
    "asian futsal": "كرة صالات آسيوية",
    "asian ice hockey": "هوكي جليد آسيوية",
    "asian rugby league competitions": "منافسات دوري رجبي آسيوية",
    "australian basketball": "كرة سلة أسترالية",
    "australian college": "كليات أسترالية",
    "australian cricket": "كريكت أسترالية",
    "australian domestic cricket": "كريكت أسترالية محلية",
    "australian field hockey": "هوكي ميدان أسترالية",
    "australian football clubs": "أندية كرة قدم أسترالية",
    "australian netball": "كرة شبكة أسترالية",
    "australian soccer leagues": "دوريات كرة قدم أسترالية",
    "austrian basketball": "كرة سلة نمساوية",
    "austrian football leagues": "دوريات كرة قدم نمساوية",
    "austrian ice hockey leagues": "دوريات هوكي جليد نمساوية",
    "austrian ice hockey": "هوكي جليد نمساوية",
    "azerbaijani football leagues": "دوريات كرة قدم أذربيجانية",
    "bahraini football leagues": "دوريات كرة قدم بحرينية",
    "bangladesh cricket": "كريكت بنغلاديشية",
    "bangladeshi cricket": "كريكت بنغلاديشية",
    "basque football competitions": "منافسات كرة قدم باسكية",
    "belarusian basketball": "كرة سلة بيلاروسية",
    "belarusian ice hockey": "هوكي جليد بيلاروسية",
    "belgian basketball": "كرة سلة بلجيكية",
    "belgian cricket": "كريكت بلجيكية",
    "belgian football chairmen and investors": "رؤساء ومسيرو كرة قدم بلجيكية",
    "belgian football leagues": "دوريات كرة قدم بلجيكية",
    "belgian ice hockey": "هوكي جليد بلجيكية",
    "bosnia and herzegovina football leagues": "دوريات كرة قدم بوسنية",
    "brazilian football leagues": "دوريات كرة قدم برازيلية",
    "brazilian martial arts": "فنون قتالية برازيلية",
    "british basketball leagues": "دوريات كرة سلة بريطانية",
    "british basketball": "كرة سلة بريطانية",
    "british ice hockey": "هوكي جليد بريطانية",
    "bulgarian basketball": "كرة سلة بلغارية",
    "bulgarian football leagues": "دوريات كرة قدم بلغارية",
    "bulgarian ice hockey": "هوكي جليد بلغارية",
    "canadian basketball": "كرة سلة كندية",
    "canadian cricket": "كريكت كندية",
    "canadian curling": "كيرلنغ كندية",
    "canadian domestic cricket competitions": "منافسات كريكت كندية محلية",
    "canadian domestic cricket": "كريكت كندية محلية",
    "canadian ice hockey": "هوكي جليد كندية",
    "chinese basketball": "كرة سلة صينية",
    "chinese football leagues": "دوريات كرة قدم صينية",
    "croatian basketball": "كرة سلة كرواتية",
    "croatian ice hockey": "هوكي جليد كرواتية",
    "czech basketball": "كرة سلة تشيكية",
    "czech football clubs": "أندية كرة قدم تشيكية",
    "czech ice hockey leagues": "دوريات هوكي جليد تشيكية",
    "czech ice hockey": "هوكي جليد تشيكية",
    "czechoslovak ice hockey": "هوكي جليد تشيكوسلوفاكية",
    "danish football leagues": "دوريات كرة قدم دنماركية",
    "danish ice hockey": "هوكي جليد دنماركية",
    "dutch basketball": "كرة سلة هولندية",
    "dutch cricket": "كريكت هولندية",
    "dutch football leagues": "دوريات كرة قدم هولندية",
    "emirati cricket": "كريكت إماراتية",
    "emirati football clubs": "أندية كرة قدم إماراتية",
    "english cricket": "كريكت إنجليزية",
    "english football leagues": "دوريات كرة قدم إنجليزية",
    "english football teams": "فرق كرة قدم إنجليزية",
    "english netball": "كرة شبكة إنجليزية",
    "estonian basketball": "كرة سلة إستونية",
    "estonian ice hockey": "هوكي جليد إستونية",
    "european basketball leagues": "دوريات كرة سلة أوروبية",
    "european basketball": "كرة سلة أوروبية",
    "european field hockey": "هوكي ميدان أوروبية",
    "european football leagues": "دوريات كرة قدم أوروبية",
    "european futsal leagues": "دوريات كرة صالات أوروبية",
    "european futsal": "كرة صالات أوروبية",
    "european ice hockey leagues": "دوريات هوكي جليد أوروبية",
    "european ice hockey": "هوكي جليد أوروبية",
    "european volleyball leagues": "دوريات كرة طائرة أوروبية",
    "european water polo": "كرة ماء أوروبية",
    "faroese football leagues": "دوريات كرة قدم فاروية",
    "finnish basketball": "كرة سلة فنلندية",
    "finnish ice hockey": "هوكي جليد فنلندية",
    "french basketball": "كرة سلة فرنسية",
    "french ice hockey": "هوكي جليد فرنسية",
    "georgian basketball": "كرة سلة جورجية",
    "german basketball": "كرة سلة ألمانية",
    "german football leagues": "دوريات كرة قدم ألمانية",
    "german ice hockey": "هوكي جليد ألمانية",
    "german martial arts": "فنون قتالية ألمانية",
    "greek basketball": "كرة سلة يونانية",
    "greek football leagues": "دوريات كرة قدم يونانية",
    "greek ice hockey": "هوكي جليد يونانية",
    "hong kong basketball": "كرة سلة هونغ كونغية",
    "hong kong football leagues": "دوريات كرة قدم هونغ كونغية",
    "hungarian basketball": "كرة سلة مجرية",
    "hungarian handball": "كرة يد مجرية",
    "hungarian ice hockey": "هوكي جليد مجرية",
    "hungarian water polo competitions": "منافسات كرة ماء مجرية",
    "hungarian water polo": "كرة ماء مجرية",
    "icelandic basketball": "كرة سلة آيسلندية",
    "icelandic ice hockey": "هوكي جليد آيسلندية",
    "indian basketball": "كرة سلة هندية",
    "indian cricket": "كريكت هندية",
    "indian football leagues": "دوريات كرة قدم هندية",
    "indonesian basketball": "كرة سلة إندونيسية",
    "indonesian football competitions": "منافسات كرة قدم إندونيسية",
    "indonesian football leagues": "دوريات كرة قدم إندونيسية",
    "iranian football leagues": "دوريات كرة قدم إيرانية",
    "iranian futsal leagues": "دوريات كرة صالات إيرانية",
    "iraqi football leagues": "دوريات كرة قدم عراقية",
    "irish college": "كليات أيرلندية",
    "irish cricket": "كريكت أيرلندية",
    "irish domestic cricket competitions": "منافسات كريكت أيرلندية محلية",
    "israeli basketball": "كرة سلة إسرائيلية",
    "israeli football leagues": "دوريات كرة قدم إسرائيلية",
    "israeli ice hockey": "هوكي جليد إسرائيلية",
    "italian basketball": "كرة سلة إيطالية",
    "italian football leagues": "دوريات كرة قدم إيطالية",
    "italian ice hockey": "هوكي جليد إيطالية",
    "japanese football leagues": "دوريات كرة قدم يابانية",
    "japanese ice hockey": "هوكي جليد يابانية",
    "jordanian basketball": "كرة سلة أردنية",
    "kazakhstani basketball": "كرة سلة كازاخستانية",
    "kazakhstani ice hockey": "هوكي جليد كازاخستانية",
    "kenyan cricket": "كريكت كينية",
    "latvian basketball": "كرة سلة لاتفية",
    "latvian ice hockey": "هوكي جليد لاتفية",
    "lebanese basketball": "كرة سلة لبنانية",
    "lebanese football leagues": "دوريات كرة قدم لبنانية",
    "lithuanian basketball": "كرة سلة ليتوانية",
    "lithuanian ice hockey": "هوكي جليد ليتوانية",
    "malaysian basketball": "كرة سلة ماليزية",
    "malaysian cricket": "كريكت ماليزية",
    "malaysian football competitions": "منافسات كرة قدم ماليزية",
    "moldovan football clubs": "أندية كرة قدم مولدوفية",
    "nepalese cricket": "كريكت نيبالية",
    "nepalese domestic cricket competitions": "منافسات كريكت نيبالية محلية",
    "nigerian basketball": "كرة سلة نيجيرية",
    "nordic skiing competitions": "منافسات تزلج نوردية",
    "nordic skiing": "تزلج نوردية",
    "north american basketball": "كرة سلة أمريكية شمالية",
    "north american futsal": "كرة صالات أمريكية شمالية",
    "north american martial arts": "فنون قتالية أمريكية شمالية",
    "norwegian football leagues": "دوريات كرة قدم نرويجية",
    "norwegian ice hockey": "هوكي جليد نرويجية",
    "oceanian basketball": "كرة سلة أوقيانوسية",
    "oceanian football leagues": "دوريات كرة قدم أوقيانوسية",
    "oceanian futsal": "كرة صالات أوقيانوسية",
    "omani cricket": "كريكت عمانية",
    "pakistani cricket": "كريكت باكستانية",
    "panamanian football leagues": "دوريات كرة قدم بنمية",
    "peruvian football leagues": "دوريات كرة قدم بيروية",
    "philippine basketball leagues": "دوريات كرة سلة فلبينية",
    "philippine basketball": "كرة سلة فلبينية",
    "philippine volleyball leagues": "دوريات كرة طائرة فلبينية",
    "polish basketball": "كرة سلة بولندية",
    "polish football clubs": "أندية كرة قدم بولندية",
    "polish ice hockey": "هوكي جليد بولندية",
    "portuguese auto racing teams": "فرق سباق سيارات برتغالية",
    "portuguese basketball": "كرة سلة برتغالية",
    "portuguese football leagues": "دوريات كرة قدم برتغالية",
    "republic-of ireland football leagues": "دوريات كرة قدم أيرلندية",
    "republic-of ireland football": "كرة قدم أيرلندية",
    "romanian basketball": "كرة سلة رومانية",
    "romanian ice hockey": "هوكي جليد رومانية",
    "russian basketball": "كرة سلة روسية",
    "russian football chairmen and investors": "رؤساء ومسيرو كرة قدم روسية",
    "russian football leagues": "دوريات كرة قدم روسية",
    "russian football teams": "فرق كرة قدم روسية",
    "russian ice hockey leagues": "دوريات هوكي جليد روسية",
    "russian ice hockey": "هوكي جليد روسية",
    "scottish cricket": "كريكت إسكتلندية",
    "scottish football leagues": "دوريات كرة قدم إسكتلندية",
    "serbian basketball": "كرة سلة صربية",
    "serbian football leagues": "دوريات كرة قدم صربية",
    "serbian ice hockey": "هوكي جليد صربية",
    "slovak basketball": "كرة سلة سلوفاكية",
    "slovak football leagues": "دوريات كرة قدم سلوفاكية",
    "slovak ice hockey leagues": "دوريات هوكي جليد سلوفاكية",
    "slovak ice hockey": "هوكي جليد سلوفاكية",
    "slovenian basketball": "كرة سلة سلوفينية",
    "slovenian ice hockey": "هوكي جليد سلوفينية",
    "south american basketball": "كرة سلة أمريكية جنوبية",
    "south american futsal": "كرة صالات أمريكية جنوبية",
    "south korean basketball": "كرة سلة كورية جنوبية",
    "soviet football leagues": "دوريات كرة قدم سوفيتية",
    "soviet ice hockey": "هوكي جليد سوفيتية",
    "spanish basketball ": "كرة سلة إسبانية",
    "spanish basketball leagues": "دوريات كرة سلة إسبانية",
    "spanish basketball": "كرة سلة إسبانية",
    "spanish football leagues": "دوريات كرة قدم إسبانية",
    "spanish futsal": "كرة صالات إسبانية",
    "spanish handball": "كرة يد إسبانية",
    "spanish ice hockey": "هوكي جليد إسبانية",
    "sri lankan cricket": "كريكت سريلانكية",
    "sri lankan martial arts": "فنون قتالية سريلانكية",
    "swedish basketball": "كرة سلة سويدية",
    "swedish football leagues": "دوريات كرة قدم سويدية",
    "swedish ice hockey leagues": "دوريات هوكي جليد سويدية",
    "swedish ice hockey": "هوكي جليد سويدية",
    "swiss ice hockey": "هوكي جليد سويسرية",
    "thai basketball": "كرة سلة تايلندية",
    "thai football chairmen and investors": "رؤساء ومسيرو كرة قدم تايلندية",
    "thai football leagues": "دوريات كرة قدم تايلندية",
    "tunisian football clubs": "أندية كرة قدم تونسية",
    "turkish basketball": "كرة سلة تركية",
    "turkish football chairmen and investors": "رؤساء ومسيرو كرة قدم تركية",
    "turkish ice hockey": "هوكي جليد تركية",
    "ugandan cricket": "كريكت أوغندية",
    "ukrainian basketball": "كرة سلة أوكرانية",
    "ukrainian football clubs": "أندية كرة قدم أوكرانية",
    "ukrainian football leagues": "دوريات كرة قدم أوكرانية",
    "uruguayan football chairmen and investors": "رؤساء ومسيرو كرة قدم أوروغويانية",
    "uzbekistani football leagues": "دوريات كرة قدم أوزبكستانية",
    "vietnamese basketball": "كرة سلة فيتنامية",
    "vietnamese martial arts": "فنون قتالية فيتنامية",
    "welsh football leagues": "دوريات كرة قدم ويلزية",
    "west german ice hockey": "هوكي جليد ألمانية غربية",
    "Yemeni under-13 baseball teams": "فرق كرة قاعدة يمنية تحت 13 سنة",
    "yugoslav basketball clubs": "أندية كرة سلة يوغسلافية",
    "yugoslav basketball": "كرة سلة يوغسلافية",
    "yugoslav ice hockey": "هوكي جليد يوغسلافية",
    "zimbabwean cricket": "كريكت زيمبابوية",
}

data_womens = {
    "european national womens volleyball teams": "منتخبات كرة طائرة وطنية أوروبية للسيدات",
    "european national womens volleyball teams players": "لاعبات منتخبات كرة طائرة وطنية أوروبية للسيدات",
    "african women's football": "كرة قدم إفريقية نسائية",
    "algerian women's football": "كرة قدم جزائرية نسائية",
    "american women's basketball": "كرة سلة أمريكية نسائية",
    "american women's ice hockey": "هوكي جليد أمريكية نسائية",
    "american women's soccer": "كرة قدم أمريكية نسائية",
    "asian women's football": "كرة قدم آسيوية نسائية",
    "australian women's field hockey": "هوكي ميدان أسترالية نسائية",
    "australian women's soccer": "كرة قدم أسترالية نسائية",
    "belarusian women's football": "كرة قدم بيلاروسية نسائية",
    "belgian women's football": "كرة قدم بلجيكية نسائية",
    "brazilian women's football": "كرة قدم برازيلية نسائية",
    "bulgarian women's football": "كرة قدم بلغارية نسائية",
    "Canadian women's ice hockey": "هوكي جليد كندية نسائية",
    "canadian women's ice hockey": "هوكي جليد كندية نسائية",
    "canadian women's soccer": "كرة قدم كندية نسائية",
    "chinese women's football": "كرة قدم صينية نسائية",
    "croatian women's football": "كرة قدم كرواتية نسائية",
    "czech women's football": "كرة قدم تشيكية نسائية",
    "danish women's football": "كرة قدم دنماركية نسائية",
    "dutch women's football": "كرة قدم هولندية نسائية",
    "english women's football": "كرة قدم إنجليزية نسائية",
    "estonian women's football": "كرة قدم إستونية نسائية",
    "european women's basketball": "كرة سلة أوروبية نسائية",
    "european women's football": "كرة قدم أوروبية نسائية",
    "finnish women's football": "كرة قدم فنلندية نسائية",
    "french women's football": "كرة قدم فرنسية نسائية",
    "german women's football": "كرة قدم ألمانية نسائية",
    "indian women's cricket": "كريكت هندية نسائية",
    "indian women's football": "كرة قدم هندية نسائية",
    "israeli women's football": "كرة قدم إسرائيلية نسائية",
    "italian women's football": "كرة قدم إيطالية نسائية",
    "japanese women's football": "كرة قدم يابانية نسائية",
    "jordanian women's football": "كرة قدم أردنية نسائية",
    "north american women's football": "كرة قدم أمريكية شمالية نسائية",
    "norwegian women's football": "كرة قدم نرويجية نسائية",
    "oceanian women's football": "كرة قدم أوقيانوسية نسائية",
    "portuguese women's football": "كرة قدم برتغالية نسائية",
    "romanian women's football": "كرة قدم رومانية نسائية",
    "samoan women's football": "كرة قدم ساموية نسائية",
    "scottish women's football": "كرة قدم إسكتلندية نسائية",
    "spanish women's football": "كرة قدم إسبانية نسائية",
    "swedish women's football": "كرة قدم سويدية نسائية",
    "swiss women's football": "كرة قدم سويسرية نسائية",
    "turkish women's football": "كرة قدم تركية نسائية",
    "west german women's football": "كرة قدم ألمانية غربية نسائية",
}

data_2 = {
    "russian football teams": "فرق كرة قدم روسية",
    "american football teams": "فرق كرة قدم أمريكية",
    "american football competitions": "منافسات كرة قدم أمريكية",
    "north american football leagues": "دوريات كرة قدم أمريكية شمالية",
    "central american football leagues": "دوريات كرة قدم أمريكية أوسطية",
    "south american football leagues": "دوريات كرة قدم أمريكية جنوبية",
}


@pytest.mark.parametrize("key,expected", data_0.items(), ids=data_0.keys())
@pytest.mark.fast
def test_sport_lab_nat_load_0(key: str, expected: str) -> None:
    result2 = sport_lab_nat_load_new(key)
    assert result2 == expected


@pytest.mark.parametrize("key,expected", data_1.items(), ids=data_1.keys())
@pytest.mark.skip2
def test_sport_lab_nat_load_1(key: str, expected: str) -> None:
    result2 = sport_lab_nat_load_new(key)
    assert result2 == expected


@pytest.mark.parametrize("key,expected", data_womens.items(), ids=data_womens.keys())
@pytest.mark.fast
def test_sport_lab_nat_load_3(key: str, expected: str) -> None:
    result2 = sport_lab_nat_load_new(key)
    assert result2 == expected


@pytest.mark.parametrize("key,expected", data_2.items(), ids=data_2.keys())
@pytest.mark.fast
def test_compare(key: str, expected: str) -> None:
    """
    Important because keys like: (canadian football, american football) are in both Nationality and SPORTS_KEYS
    """
    # pytest tests/translations/sports_formats_teams/test_sport_lab_nat_compare.py -m skip2

    result2 = sport_lab_nat_load_new(key)

    assert result2 == expected


@pytest.mark.fast
def test_the_compare() -> None:
    key = "the yemeni people under-13 baseball teams"
    expected = "فرق كرة قاعدة يمنية تحت 13 سنة"

    result2 = sport_lab_nat_load_new(key)

    assert result2 == expected, f"Error: {result2=}, {expected=}"


to_test = [
    ("test_sport_lab_nat_load_0", data_0),
    # ("test_sport_lab_nat_load_1", data_1),
    ("test_sport_lab_nat_load_2", data_2),
    ("test_sport_lab_nat_load_3", data_womens),
]


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, sport_lab_nat_load_new)
    dump_diff(diff_result, name)

    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



from __future__ import annotations

import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats.new_resolvers.relations_resolver import new_relations_resolvers

ireland_test_data = {
    "russia–south sudan relations": "العلاقات الروسية السودانية الجنوبية",
    "saudi arabia–south sudan relations": "العلاقات السعودية السودانية الجنوبية",
    "slovenia–south sudan relations": "العلاقات السلوفينية السودانية الجنوبية",
    "south sudan–sudan border": "الحدود السودانية السودانية الجنوبية",
    "south sudan–sudan relations": "العلاقات السودانية السودانية الجنوبية",
    "cameroon–north macedonia relations": "العلاقات الكاميرونية المقدونية الشمالية",
    "canada–north macedonia relations": "العلاقات الكندية المقدونية الشمالية",
    "canada–north yemen relations": "العلاقات الكندية اليمنية الشمالية",
    "canada–south yemen relations": "العلاقات الكندية اليمنية الجنوبية",
    "china–north macedonia relations": "العلاقات الصينية المقدونية الشمالية",
    "china–south yemen relations": "العلاقات الصينية اليمنية الجنوبية",
    "colombia–north macedonia relations": "العلاقات الكولومبية المقدونية الشمالية",
    "croatia–north macedonia relations": "العلاقات الكرواتية المقدونية الشمالية",
    "cuba–south yemen relations": "العلاقات الكوبية اليمنية الجنوبية",
    "cyprus–north macedonia relations": "العلاقات القبرصية المقدونية الشمالية",
    "democratic-republic-of-congo–north macedonia relations": "العلاقات الكونغوية الديمقراطية المقدونية الشمالية",
    "denmark–south sudan relations": "العلاقات الدنماركية السودانية الجنوبية",
    "egypt–north macedonia relations": "العلاقات المصرية المقدونية الشمالية",
    "equatorial guinea–north macedonia relations": "العلاقات الغينية الاستوائية المقدونية الشمالية",
    "finland–north macedonia relations": "العلاقات الفنلندية المقدونية الشمالية",
    "france–north macedonia relations": "العلاقات الفرنسية المقدونية الشمالية",
    "ghana–north macedonia relations": "العلاقات الغانية المقدونية الشمالية",
    "guinea–north macedonia relations": "العلاقات الغينية المقدونية الشمالية",
    "hungary–north macedonia relations": "العلاقات المجرية المقدونية الشمالية",
    "kazakhstan–north macedonia relations": "العلاقات الكازاخستانية المقدونية الشمالية",
    "kosovo–north macedonia border crossings": "معابر الحدود الكوسوفية المقدونية الشمالية",
    "kosovo–north macedonia border": "الحدود الكوسوفية المقدونية الشمالية",
    "kosovo–north macedonia relations": "العلاقات الكوسوفية المقدونية الشمالية",
    "latvia–north macedonia relations": "العلاقات اللاتفية المقدونية الشمالية",
    "liechtenstein–north macedonia relations": "العلاقات الليختنشتانية المقدونية الشمالية",
    "lithuania–north macedonia relations": "العلاقات الليتوانية المقدونية الشمالية",
    "luxembourg–north macedonia relations": "العلاقات اللوكسمبورغية المقدونية الشمالية",
    "malaysia–north macedonia relations": "العلاقات الماليزية المقدونية الشمالية",
    "maldives–north macedonia relations": "العلاقات المالديفية المقدونية الشمالية",
    "morocco–north macedonia relations": "العلاقات المغربية المقدونية الشمالية",
    "south korea–yemen relations": "العلاقات الكورية الجنوبية اليمنية",
    "afghanistan–ireland relations": "العلاقات الأفغانية الأيرلندية",
    "afghanistan–ireland sports relations": "العلاقات الأفغانية الأيرلندية الرياضية",
    "albania–ireland relations": "العلاقات الألبانية الأيرلندية",
    "algeria–ireland relations": "العلاقات الأيرلندية الجزائرية",
    "andorra–ireland relations": "العلاقات الأندورية الأيرلندية",
    "angola–ireland relations": "العلاقات الأنغولية الأيرلندية",
    "antigua and barbuda–ireland relations": "العلاقات الأنتيغوية والبربودية الأيرلندية",
    "argentina–ireland relations": "العلاقات الأرجنتينية الأيرلندية",
    "argentina–ireland sports relations": "العلاقات الأرجنتينية الأيرلندية الرياضية",
    "armenia–ireland relations": "العلاقات الأرمينية الأيرلندية",
    "australia–ireland relations": "العلاقات الأسترالية الأيرلندية",
    "australia–ireland sports relations": "العلاقات الأسترالية الأيرلندية الرياضية",
    "austria–ireland relations": "العلاقات الأيرلندية النمساوية",
    "azerbaijan–ireland relations": "العلاقات الأذربيجانية الأيرلندية",
    "bahamas–ireland relations": "العلاقات الأيرلندية البهامية",
    "bahrain–ireland relations": "العلاقات الأيرلندية البحرينية",
    "bangladesh–ireland relations": "العلاقات الأيرلندية البنغلاديشية",
    "bangladesh–ireland sports relations": "العلاقات الأيرلندية البنغلاديشية الرياضية",
    "barbados–ireland relations": "العلاقات الأيرلندية البربادوسية",
    "belarus–ireland relations": "العلاقات الأيرلندية البيلاروسية",
    "belgium–ireland relations": "العلاقات الأيرلندية البلجيكية",
    "benin–ireland relations": "العلاقات الأيرلندية البنينية",
    "bolivia–ireland relations": "العلاقات الأيرلندية البوليفية",
    "bosnia and herzegovina–ireland relations": "العلاقات الأيرلندية البوسنية",
    "brazil–ireland relations": "العلاقات الأيرلندية البرازيلية",
    "brunei–ireland relations": "العلاقات الأيرلندية البرونية",
    "bulgaria–ireland relations": "العلاقات الأيرلندية البلغارية",
    "burkina faso–ireland relations": "العلاقات الأيرلندية البوركينابية",
    "burundi–ireland relations": "العلاقات الأيرلندية البوروندية",
    "cambodia–ireland relations": "العلاقات الأيرلندية الكمبودية",
    "cameroon–ireland relations": "العلاقات الأيرلندية الكاميرونية",
    "canada–ireland relations": "العلاقات الأيرلندية الكندية",
    "canada–ireland sports relations": "العلاقات الأيرلندية الكندية الرياضية",
    "cape verde–ireland relations": "العلاقات الأيرلندية الرأس الأخضرية",
    "central african republic–ireland relations": "العلاقات الأيرلندية الإفريقية الأوسطية",
    "chile–ireland relations": "العلاقات الأيرلندية التشيلية",
    "china–ireland relations": "العلاقات الأيرلندية الصينية",
    "colombia–ireland relations": "العلاقات الأيرلندية الكولومبية",
    "costa rica–ireland relations": "العلاقات الأيرلندية الكوستاريكية",
    "croatia–ireland relations": "العلاقات الأيرلندية الكرواتية",
    "cuba–ireland relations": "العلاقات الأيرلندية الكوبية",
    "cyprus–ireland relations": "العلاقات الأيرلندية القبرصية",
    "czech republic–ireland relations": "العلاقات الأيرلندية التشيكية",
    "czechoslovakia–ireland relations": "العلاقات الأيرلندية التشيكوسلوفاكية",
    "denmark–ireland relations": "العلاقات الأيرلندية الدنماركية",
    "dominican republic–ireland relations": "العلاقات الأيرلندية الدومينيكانية",
    "ecuador–ireland relations": "العلاقات الأيرلندية الإكوادورية",
    "egypt–ireland relations": "العلاقات الأيرلندية المصرية",
    "el salvador–ireland relations": "العلاقات الأيرلندية السلفادورية",
    "england–ireland relations": "العلاقات الأيرلندية الإنجليزية",
    "estonia–ireland relations": "العلاقات الأيرلندية الإستونية",
    "ethiopia–ireland relations": "العلاقات الأيرلندية الإثيوبية",
    "fiji–ireland relations": "العلاقات الأيرلندية الفيجية",
    "fiji–ireland sports relations": "العلاقات الأيرلندية الفيجية الرياضية",
    "finland–ireland relations": "العلاقات الأيرلندية الفنلندية",
    "france–ireland relations": "العلاقات الأيرلندية الفرنسية",
    "france–ireland sports relations": "العلاقات الأيرلندية الفرنسية الرياضية",
    "gambia–ireland relations": "العلاقات الأيرلندية الغامبية",
    "georgia (country)–ireland relations": "العلاقات الأيرلندية الجورجية",
    "germany–ireland relations": "العلاقات الألمانية الأيرلندية",
    "ghana–ireland relations": "العلاقات الأيرلندية الغانية",
    "greece–ireland relations": "العلاقات الأيرلندية اليونانية",
    "guatemala–ireland relations": "العلاقات الأيرلندية الغواتيمالية",
    "guinea-bissau–ireland relations": "العلاقات الأيرلندية الغينية البيساوية",
    "guyana–ireland relations": "العلاقات الأيرلندية الغيانية",
    "haiti–ireland relations": "العلاقات الأيرلندية الهايتية",
    "honduras–ireland relations": "العلاقات الأيرلندية الهندوراسية",
    "hong kong–ireland relations": "العلاقات الأيرلندية الهونغ الكونغية",
    "hungary–ireland relations": "العلاقات الأيرلندية المجرية",
    "iceland–ireland relations": "العلاقات الآيسلندية الأيرلندية",
    "india–ireland relations": "العلاقات الأيرلندية الهندية",
    "india–ireland sports relations": "العلاقات الأيرلندية الهندية الرياضية",
    "indonesia–ireland relations": "العلاقات الأيرلندية الإندونيسية",
    "iran–ireland relations": "العلاقات الأيرلندية الإيرانية",
    "iraq–ireland relations": "العلاقات الأيرلندية العراقية",
    "ireland–israel relations": "العلاقات الأيرلندية الإسرائيلية",
    "ireland–italy relations": "العلاقات الأيرلندية الإيطالية",
    "ireland–italy sports relations": "العلاقات الأيرلندية الإيطالية الرياضية",
    "ireland–ivory coast relations": "العلاقات الأيرلندية الإيفوارية",
    "ireland–jamaica relations": "العلاقات الأيرلندية الجامايكية",
    "ireland–japan relations": "العلاقات الأيرلندية اليابانية",
    "ireland–jordan relations": "العلاقات الأردنية الأيرلندية",
    "ireland–kazakhstan relations": "العلاقات الأيرلندية الكازاخستانية",
    "ireland–kenya relations": "العلاقات الأيرلندية الكينية",
    "ireland–kenya sports relations": "العلاقات الأيرلندية الكينية الرياضية",
    "ireland–kosovo relations": "العلاقات الأيرلندية الكوسوفية",
    "ireland–kyrgyzstan relations": "العلاقات الأيرلندية القيرغيزستانية",
    "ireland–latvia relations": "العلاقات الأيرلندية اللاتفية",
    "ireland–lesotho relations": "العلاقات الأيرلندية الليسوتية",
    "ireland–libya relations": "العلاقات الأيرلندية الليبية",
    "ireland–liechtenstein relations": "العلاقات الأيرلندية الليختنشتانية",
    "ireland–lithuania relations": "العلاقات الأيرلندية الليتوانية",
    "ireland–luxembourg relations": "العلاقات الأيرلندية اللوكسمبورغية",
    "ireland–malawi relations": "العلاقات الأيرلندية الملاوية",
    "ireland–malaysia relations": "العلاقات الأيرلندية الماليزية",
    "ireland–mali relations": "العلاقات الأيرلندية المالية",
    "ireland–malta relations": "العلاقات الأيرلندية المالطية",
    "ireland–mexico relations": "العلاقات الأيرلندية المكسيكية",
    "ireland–moldova relations": "العلاقات الأيرلندية المولدوفية",
    "ireland–mongolia relations": "العلاقات الأيرلندية المنغولية",
    "ireland–montenegro relations": "العلاقات الأيرلندية المونتينيغرية",
    "ireland–morocco relations": "العلاقات الأيرلندية المغربية",
    "ireland–myanmar relations": "العلاقات الأيرلندية الميانمارية",
    "ireland–namibia relations": "العلاقات الأيرلندية الناميبية",
    "ireland–namibia sports relations": "العلاقات الأيرلندية الناميبية الرياضية",
    "ireland–nepal relations": "العلاقات الأيرلندية النيبالية",
    "ireland–netherlands relations": "العلاقات الأيرلندية الهولندية",
    "ireland–netherlands sports relations": "العلاقات الأيرلندية الهولندية الرياضية",
    "ireland–new zealand relations": "العلاقات الأيرلندية النيوزيلندية",
    "ireland–new zealand sports relations": "العلاقات الأيرلندية النيوزيلندية الرياضية",
    "ireland–nicaragua relations": "العلاقات الأيرلندية النيكاراغوية",
    "ireland–nigeria relations": "العلاقات الأيرلندية النيجيرية",
    "ireland–norway relations": "العلاقات الأيرلندية النرويجية",
    "ireland–pakistan relations": "العلاقات الأيرلندية الباكستانية",
    "ireland–pakistan sports relations": "العلاقات الأيرلندية الباكستانية الرياضية",
    "ireland–palestine relations": "العلاقات الأيرلندية الفلسطينية",
    "ireland–panama relations": "العلاقات الأيرلندية البنمية",
    "ireland–paraguay relations": "العلاقات الأيرلندية البارغوايانية",
    "ireland–peru relations": "العلاقات الأيرلندية البيروية",
    "ireland–philippines relations": "العلاقات الأيرلندية الفلبينية",
    "ireland–poland relations": "العلاقات الأيرلندية البولندية",
    "ireland–portugal relations": "العلاقات الأيرلندية البرتغالية",
    "ireland–qatar relations": "العلاقات الأيرلندية القطرية",
    "ireland–romania relations": "العلاقات الأيرلندية الرومانية",
    "ireland–russia relations": "العلاقات الأيرلندية الروسية",
    "ireland–rwanda relations": "العلاقات الأيرلندية الرواندية",
    "ireland–samoa relations": "العلاقات الأيرلندية الساموية",
    "ireland–saudi arabia relations": "العلاقات الأيرلندية السعودية",
    "ireland–scotland relations": "العلاقات الأيرلندية الإسكتلندية",
    "ireland–senegal relations": "العلاقات الأيرلندية السنغالية",
    "ireland–serbia relations": "العلاقات الأيرلندية الصربية",
    "ireland–sierra leone relations": "العلاقات الأيرلندية السيراليونية",
    "ireland–singapore relations": "العلاقات الأيرلندية السنغافورية",
    "ireland–slovakia relations": "العلاقات الأيرلندية السلوفاكية",
    "ireland–slovenia relations": "العلاقات الأيرلندية السلوفينية",
    "ireland–somalia relations": "العلاقات الأيرلندية الصومالية",
    "ireland–south korea relations": "العلاقات الأيرلندية الكورية الجنوبية",
    "ireland–soviet union relations": "العلاقات الأيرلندية السوفيتية",
    "ireland–spain relations": "العلاقات الأيرلندية الإسبانية",
    "ireland–spain sports relations": "العلاقات الأيرلندية الإسبانية الرياضية",
    "ireland–sri lanka relations": "العلاقات الأيرلندية السريلانكية",
    "ireland–sri lanka sports relations": "العلاقات الأيرلندية السريلانكية الرياضية",
    "ireland–sudan relations": "العلاقات الأيرلندية السودانية",
    "ireland–sweden relations": "العلاقات الأيرلندية السويدية",
    "ireland–switzerland relations": "العلاقات الأيرلندية السويسرية",
    "ireland–taiwan relations": "العلاقات الأيرلندية التايوانية",
    "ireland–tajikistan relations": "العلاقات الأيرلندية الطاجيكستانية",
    "ireland–tanzania relations": "العلاقات الأيرلندية التنزانية",
    "ireland–thailand relations": "العلاقات الأيرلندية التايلندية",
    "ireland–tonga relations": "العلاقات الأيرلندية التونغانية",
    "ireland–trinidad and tobago relations": "العلاقات الأيرلندية الترنيدادية",
    "ireland–tunisia relations": "العلاقات الأيرلندية التونسية",
    "ireland–turkey relations": "العلاقات الأيرلندية التركية",
    "ireland–uganda relations": "العلاقات الأوغندية الأيرلندية",
    "ireland–ukraine relations": "العلاقات الأوكرانية الأيرلندية",
    "ireland–united arab emirates relations": "العلاقات الأيرلندية الإماراتية",
    "ireland–united arab emirates sports relations": "العلاقات الأيرلندية الإماراتية الرياضية",
    "ireland–united kingdom relations": "العلاقات الأيرلندية البريطانية",
    "ireland–united kingdom sports relations": "العلاقات الأيرلندية البريطانية الرياضية",
    "ireland–united states relations": "العلاقات الأمريكية الأيرلندية",
    "ireland–united states sports relations": "العلاقات الأمريكية الأيرلندية الرياضية",
    "ireland–uruguay relations": "العلاقات الأوروغويانية الأيرلندية",
    "ireland–uzbekistan relations": "العلاقات الأوزبكستانية الأيرلندية",
    "ireland–venezuela relations": "العلاقات الأيرلندية الفنزويلية",
    "ireland–vietnam relations": "العلاقات الأيرلندية الفيتنامية",
    "ireland–west germany relations": "العلاقات الألمانية الغربية الأيرلندية",
    "ireland–yugoslavia relations": "العلاقات الأيرلندية اليوغسلافية",
    "ireland–zambia relations": "العلاقات الأيرلندية الزامبية",
    "ireland–zimbabwe relations": "العلاقات الأيرلندية الزيمبابوية",
    "ireland–zimbabwe sports relations": "العلاقات الأيرلندية الزيمبابوية الرياضية",
}

test_data = {
    "Georgia (country)–Luxembourg relations": "العلاقات الجورجية اللوكسمبورغية",
    "France–Papua New Guinea relations": "العلاقات الغينية الفرنسية",
    "Angola–Guinea-Bissau relations": "العلاقات الأنغولية الغينية البيساوية",
    "Azerbaijan–Guinea-Bissau relations": "العلاقات الأذربيجانية الغينية البيساوية",
    "Belgium–Guinea-Bissau relations": "العلاقات البلجيكية الغينية البيساوية",
    "Brazil–Guinea-Bissau relations": "العلاقات البرازيلية الغينية البيساوية",
    "Bulgaria–Guinea-Bissau relations": "العلاقات البلغارية الغينية البيساوية",
    "Cape Verde–Guinea-Bissau relations": "العلاقات الرأس الأخضرية الغينية البيساوية",
    "China–Guinea-Bissau relations": "العلاقات الصينية الغينية البيساوية",
    "Cyprus–Guinea-Bissau relations": "العلاقات الغينية البيساوية القبرصية",
    "Democratic republic of congo–republic of congo border crossings": "معابر الحدود الكونغوية الكونغوية الديمقراطية",
    "Egypt–Guinea-Bissau relations": "العلاقات الغينية البيساوية المصرية",
    "Ethiopia–Guinea-Bissau relations": "العلاقات الإثيوبية الغينية البيساوية",
    "Finland–Guinea-Bissau relations": "العلاقات الغينية البيساوية الفنلندية",
    "France–Guinea-Bissau relations": "العلاقات الغينية البيساوية الفرنسية",
    "Georgia (country)–Guinea-Bissau relations": "العلاقات الجورجية الغينية البيساوية",
    "Greece–Guinea-Bissau relations": "العلاقات الغينية البيساوية اليونانية",
    "democratic-republic-of-congo–libya relations": "العلاقات الكونغوية الديمقراطية الليبية",
    "democratic-republic-of-congo–netherlands relations": "العلاقات الكونغوية الديمقراطية الهولندية",
    "ireland–sahrawi arab democratic republic relations": "علاقات أيرلندا والجمهورية العربية الصحراوية الديمقراطية",
    "abbasid caliphate–byzantine empire relations": "علاقات الإمبراطورية البيزنطية والدولة العباسية",
    "algeria–sahrawi arab democratic republic relations": "علاقات الجزائر والجمهورية العربية الصحراوية الديمقراطية",
    "angola–sahrawi arab democratic republic relations": "علاقات أنغولا والجمهورية العربية الصحراوية الديمقراطية",
    "australia–cook islands relations": "علاقات أستراليا وجزر كوك",
    "australia–sahrawi arab democratic republic relations": "علاقات أستراليا والجمهورية العربية الصحراوية الديمقراطية",
    "australia–solomon islands relations": "علاقات أستراليا وجزر سليمان",
    "australia–tibet relations": "علاقات أستراليا والتبت",
    "bangladesh–solomon islands relations": "علاقات بنغلاديش وجزر سليمان",
    "belize–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية وبليز",
    "belize–solomon islands relations": "علاقات بليز وجزر سليمان",
    "bermuda–canada relations": "علاقات برمودا وكندا",
    "bermuda–united states relations": "علاقات الولايات المتحدة وبرمودا",
    "byzantine empire–fatimid caliphate relations": "علاقات الإمبراطورية البيزنطية والدولة الفاطمية",
    "byzantine empire–holy roman empire relations": "علاقات الإمبراطورية البيزنطية والإمبراطورية الرومانية المقدسة",
    "canada–marshall islands relations": "علاقات جزر مارشال وكندا",
    "canada–solomon islands relations": "علاقات جزر سليمان وكندا",
    "canada–tibet relations": "علاقات التبت وكندا",
    "cayman islands–jamaica relations": "علاقات جامايكا وجزر كايمان",
    "cayman islands–sierra leone relations": "علاقات جزر كايمان وسيراليون",
    "china–cook islands relations": "علاقات الصين وجزر كوك",
    "china–great britain relations": "علاقات الصين وبريطانيا العظمى",
    "china–solomon islands relations": "علاقات الصين وجزر سليمان",
    "china–tibet relations": "علاقات التبت والصين",
    "cook islands–czech republic relations": "علاقات التشيك وجزر كوك",
    "cook islands–european union relations": "علاقات الاتحاد الأوروبي وجزر كوك",
    "cook islands–fiji relations": "علاقات جزر كوك وفيجي",
    "cook islands–japan relations": "علاقات اليابان وجزر كوك",
    "cook islands–new zealand relations": "علاقات جزر كوك ونيوزيلندا",
    "cook islands–papua new guinea relations": "علاقات بابوا غينيا الجديدة وجزر كوك",
    "cook islands–sweden relations": "علاقات السويد وجزر كوك",
    "cook islands–united kingdom relations": "علاقات المملكة المتحدة وجزر كوك",
    "cook islands–united states relations": "علاقات الولايات المتحدة وجزر كوك",
    "costa rica–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية وكوستاريكا",
    "cuba–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية وكوبا",
    "cuba–solomon islands relations": "علاقات جزر سليمان وكوبا",
    "czech republic–solomon islands relations": "علاقات التشيك وجزر سليمان",
    "denmark–holy roman empire relations": "علاقات الإمبراطورية الرومانية المقدسة والدنمارك",
    "dutch republic–england relations": "علاقات إنجلترا وجمهورية هولندا",
    "dutch republic–france relations": "علاقات جمهورية هولندا وفرنسا",
    "dutch republic–habsburg monarchy relations": "علاقات جمهورية هولندا وملكية هابسبورغ",
    "dutch republic–holy roman empire relations": "علاقات الإمبراطورية الرومانية المقدسة وجمهورية هولندا",
    "dutch republic–portugal relations": "علاقات البرتغال وجمهورية هولندا",
    "dutch republic–spain relations": "علاقات إسبانيا وجمهورية هولندا",
    "dutch republic–sweden relations": "علاقات السويد وجمهورية هولندا",
    "england–holy roman empire relations": "علاقات إنجلترا والإمبراطورية الرومانية المقدسة",
    "equatorial guinea–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية وغينيا الاستوائية",
    "ethiopia–sahrawi arab democratic republic relations": "علاقات إثيوبيا والجمهورية العربية الصحراوية الديمقراطية",
    "federated states-of micronesia–solomon islands relations": "علاقات جزر سليمان وولايات ميكرونيسيا المتحدة",
    "fiji–marshall islands relations": "علاقات جزر مارشال وفيجي",
    "fiji–solomon islands relations": "علاقات جزر سليمان وفيجي",
    "france–great britain relations": "علاقات بريطانيا العظمى وفرنسا",
    "france–habsburg monarchy relations": "علاقات فرنسا وملكية هابسبورغ",
    "france–holy roman empire relations": "علاقات الإمبراطورية الرومانية المقدسة وفرنسا",
    "france–marshall islands relations": "علاقات جزر مارشال وفرنسا",
    "france–solomon islands relations": "علاقات جزر سليمان وفرنسا",
    "germany–solomon islands relations": "علاقات ألمانيا وجزر سليمان",
    "germany–tibet relations": "علاقات ألمانيا والتبت",
    "ghana–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية وغانا",
    "ghana–solomon islands relations": "علاقات جزر سليمان وغانا",
    "great britain–habsburg monarchy relations": "علاقات بريطانيا العظمى وملكية هابسبورغ",
    "great britain–united states relations": "علاقات الولايات المتحدة وبريطانيا العظمى",
    "guernsey–united kingdom relations": "علاقات المملكة المتحدة وغيرنزي",
    "habsburg monarchy–holy roman empire relations": "علاقات الإمبراطورية الرومانية المقدسة وملكية هابسبورغ",
    "habsburg monarchy–ottoman empire relations": "علاقات الدولة العثمانية وملكية هابسبورغ",
    "habsburg monarchy–polish–lithuanian commonwealth relations": "علاقات الكومنولث البولندي الليتواني وملكية هابسبورغ",
    "habsburg monarchy–prussia relations": "علاقات بروسيا وملكية هابسبورغ",
    "habsburg monarchy–russia relations": "علاقات روسيا وملكية هابسبورغ",
    "habsburg monarchy–spain relations": "علاقات إسبانيا وملكية هابسبورغ",
    "holy roman empire–hungary relations": "علاقات الإمبراطورية الرومانية المقدسة والمجر",
    "holy roman empire–ottoman empire relations": "علاقات الإمبراطورية الرومانية المقدسة والدولة العثمانية",
    "holy roman empire–portugal relations": "علاقات الإمبراطورية الرومانية المقدسة والبرتغال",
    "holy roman empire–russia relations": "علاقات الإمبراطورية الرومانية المقدسة وروسيا",
    "holy roman empire–sweden relations": "علاقات الإمبراطورية الرومانية المقدسة والسويد",
    "hungary–solomon islands relations": "علاقات المجر وجزر سليمان",
    "india–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية والهند",
    "india–solomon islands relations": "علاقات الهند وجزر سليمان",
    "india–tibet relations": "علاقات التبت والهند",
    "indonesia–marshall islands relations": "علاقات إندونيسيا وجزر مارشال",
    "iran–sahrawi arab democratic republic relations": "علاقات إيران والجمهورية العربية الصحراوية الديمقراطية",
    "japan–marshall islands relations": "علاقات اليابان وجزر مارشال",
    "japan–solomon islands relations": "علاقات اليابان وجزر سليمان",
    "japan–tibet relations": "علاقات التبت واليابان",
    "kazakhstan–solomon islands relations": "علاقات جزر سليمان وكازاخستان",
    "kiribati–solomon islands relations": "علاقات جزر سليمان وكيريباتي",
    "malaysia–solomon islands relations": "علاقات جزر سليمان وماليزيا",
    "marshall islands–federated states-of micronesia relations": "علاقات جزر مارشال وولايات ميكرونيسيا المتحدة",
    "marshall islands–new zealand relations": "علاقات جزر مارشال ونيوزيلندا",
    "marshall islands–spain relations": "علاقات إسبانيا وجزر مارشال",
    "marshall islands–sweden relations": "علاقات السويد وجزر مارشال",
    "marshall islands–taiwan relations": "علاقات تايوان وجزر مارشال",
    "marshall islands–united states relations": "علاقات الولايات المتحدة وجزر مارشال",
    "mexico–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية والمكسيك",
    "mongolia–tibet relations": "علاقات التبت ومنغوليا",
    "nepal–tibet relations": "علاقات التبت ونيبال",
    "new zealand–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية ونيوزيلندا",
    "new zealand–solomon islands relations": "علاقات جزر سليمان ونيوزيلندا",
    "nicaragua–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية ونيكاراغوا",
    "nigeria–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية ونيجيريا",
    "nigeria–solomon islands relations": "علاقات جزر سليمان ونيجيريا",
    "pakistan–solomon islands relations": "علاقات باكستان وجزر سليمان",
    "palestine–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية وفلسطين",
    "panama–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية وبنما",
    "papua new guinea–solomon islands relations": "علاقات بابوا غينيا الجديدة وجزر سليمان",
    "peru–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية وبيرو",
    "romania–solomon islands relations": "علاقات جزر سليمان ورومانيا",
    "sahrawi arab democratic republic–syria relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية وسوريا",
    "sahrawi arab democratic republic–united kingdom relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية والمملكة المتحدة",
    "sahrawi arab democratic republic–united states relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية والولايات المتحدة",
    "sahrawi arab democratic republic–venezuela relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية وفنزويلا",
    "samoa–solomon islands relations": "علاقات جزر سليمان وساموا",
    "sierra leone–solomon islands relations": "علاقات جزر سليمان وسيراليون",
    "solomon islands–spain relations": "علاقات إسبانيا وجزر سليمان",
    "solomon islands–sri lanka relations": "علاقات جزر سليمان وسريلانكا",
    "solomon islands–sweden relations": "علاقات السويد وجزر سليمان",
    "solomon islands–taiwan relations": "علاقات تايوان وجزر سليمان",
    "solomon islands–uganda relations": "علاقات أوغندا وجزر سليمان",
    "solomon islands–united kingdom relations": "علاقات المملكة المتحدة وجزر سليمان",
    "solomon islands–united states relations": "علاقات الولايات المتحدة وجزر سليمان",
    "solomon islands–vietnam relations": "علاقات جزر سليمان وفيتنام",
    "switzerland–tibet relations": "علاقات التبت وسويسرا",
    "taiwan–tibet relations": "علاقات التبت وتايوان",
    "tibet–united kingdom relations": "علاقات التبت والمملكة المتحدة",
    "tibet–united states relations": "علاقات التبت والولايات المتحدة",
    "Ukraine–NATO relations": "علاقات أوكرانيا والناتو",
    "Switzerland–NATO relations": "علاقات الناتو وسويسرا",
    "Sweden–NATO relations": "علاقات السويد والناتو",
    "Serbia–NATO relations": "علاقات الناتو وصربيا",
    "Russia–NATO relations": "علاقات الناتو وروسيا",
    "Poland–NATO relations": "علاقات الناتو وبولندا",
    "Pakistan–NATO relations": "علاقات الناتو وباكستان",
    "Malta–NATO relations": "علاقات الناتو ومالطا",
    "Georgia (country)–NATO relations": "علاقات الناتو وجورجيا",
    "Bosnia and Herzegovina–NATO relations": "علاقات البوسنة والهرسك والناتو",
    "Belarus–NATO relations": "علاقات الناتو وروسيا البيضاء",
    "Azerbaijan–NATO relations": "علاقات أذربيجان والناتو",
    "Austria–NATO relations": "علاقات الناتو والنمسا",
    "Armenia–NATO relations": "علاقات أرمينيا والناتو",
    "afghanistan–european union relations": "علاقات أفغانستان والاتحاد الأوروبي",
    "albania–european union relations": "علاقات ألبانيا والاتحاد الأوروبي",
    "andorra–european union relations": "علاقات أندورا والاتحاد الأوروبي",
    "angola–european union relations": "علاقات أنغولا والاتحاد الأوروبي",
    "argentina–european union relations": "علاقات الأرجنتين والاتحاد الأوروبي",
    "armenia–european union relations": "علاقات أرمينيا والاتحاد الأوروبي",
    "australia–european union relations": "علاقات أستراليا والاتحاد الأوروبي",
    "azerbaijan–european union relations": "علاقات أذربيجان والاتحاد الأوروبي",
    "bahamas–european union relations": "علاقات الاتحاد الأوروبي وباهاماس",
    "bahrain–european union relations": "علاقات الاتحاد الأوروبي والبحرين",
    "bangladesh–european union relations": "علاقات الاتحاد الأوروبي وبنغلاديش",
    "barbados–european union relations": "علاقات الاتحاد الأوروبي وبربادوس",
    "belarus–european union relations": "علاقات الاتحاد الأوروبي وروسيا البيضاء",
    "bolivia–european union relations": "علاقات الاتحاد الأوروبي وبوليفيا",
    "bosnia and herzegovina–european union relations": "علاقات الاتحاد الأوروبي والبوسنة والهرسك",
    "botswana–european union relations": "علاقات الاتحاد الأوروبي وبوتسوانا",
    "brazil–european union relations": "علاقات الاتحاد الأوروبي والبرازيل",
    "brunei–european union relations": "علاقات الاتحاد الأوروبي وبروناي",
    "burkina faso–european union relations": "علاقات الاتحاد الأوروبي وبوركينا فاسو",
    "cambodia–european union relations": "علاقات الاتحاد الأوروبي وكمبوديا",
    "cameroon–european union relations": "علاقات الاتحاد الأوروبي والكاميرون",
    "canada–european union relations": "علاقات الاتحاد الأوروبي وكندا",
    "cape verde–european union relations": "علاقات الاتحاد الأوروبي والرأس الأخضر",
    "central african republic–european union relations": "علاقات الاتحاد الأوروبي وجمهورية إفريقيا الوسطى",
    "chad–european union relations": "علاقات الاتحاد الأوروبي وتشاد",
    "chile–european union relations": "علاقات الاتحاد الأوروبي وتشيلي",
    "china–european union relations": "علاقات الاتحاد الأوروبي والصين",
    "colombia–european union relations": "علاقات الاتحاد الأوروبي وكولومبيا",
    "cuba–european union relations": "علاقات الاتحاد الأوروبي وكوبا",
    "djibouti–european union relations": "علاقات الاتحاد الأوروبي وجيبوتي",
    "dominican republic–european union relations": "علاقات الاتحاد الأوروبي وجمهورية الدومينيكان",
    "ecuador–european union relations": "علاقات الإكوادور والاتحاد الأوروبي",
    "egypt–european union relations": "علاقات الاتحاد الأوروبي ومصر",
    "eritrea–european union relations": "علاقات إرتريا والاتحاد الأوروبي",
    "european union–ghana relations": "علاقات الاتحاد الأوروبي وغانا",
    "european union–sudan relations": "علاقات الاتحاد الأوروبي والسودان",
    "fiji–european union relations": "علاقات الاتحاد الأوروبي وفيجي",
    "georgia (country)–european union relations": "علاقات الاتحاد الأوروبي وجورجيا",
    "greenland–european union relations": "علاقات الاتحاد الأوروبي وجرينلاند",
    "guatemala–european union relations": "علاقات الاتحاد الأوروبي وغواتيمالا",
    "guyana–european union relations": "علاقات الاتحاد الأوروبي وغيانا",
    "iceland–european union relations": "علاقات آيسلندا والاتحاد الأوروبي",
    "india–european union relations": "علاقات الاتحاد الأوروبي والهند",
    "indonesia–european union relations": "علاقات إندونيسيا والاتحاد الأوروبي",
    "iran–european union relations": "علاقات إيران والاتحاد الأوروبي",
    "iraq–european union relations": "علاقات الاتحاد الأوروبي والعراق",
    "israel–european union relations": "علاقات إسرائيل والاتحاد الأوروبي",
    "ivory coast–european union relations": "علاقات الاتحاد الأوروبي وساحل العاج",
    "jamaica–european union relations": "علاقات الاتحاد الأوروبي وجامايكا",
    "japan–european union relations": "علاقات الاتحاد الأوروبي واليابان",
    "jordan–european union relations": "علاقات الأردن والاتحاد الأوروبي",
    "kazakhstan–european union relations": "علاقات الاتحاد الأوروبي وكازاخستان",
    "kosovo–european union relations": "علاقات الاتحاد الأوروبي وكوسوفو",
    "kyrgyzstan–european union relations": "علاقات الاتحاد الأوروبي وقيرغيزستان",
    "lebanon–european union relations": "علاقات الاتحاد الأوروبي ولبنان",
    "libya–european union relations": "علاقات الاتحاد الأوروبي وليبيا",
    "liechtenstein–european union relations": "علاقات الاتحاد الأوروبي وليختنشتاين",
    "madagascar–european union relations": "علاقات الاتحاد الأوروبي ومدغشقر",
    "maldives–european union relations": "علاقات الاتحاد الأوروبي وجزر المالديف",
    "mauritania–european union relations": "علاقات الاتحاد الأوروبي وموريتانيا",
    "mauritius–european union relations": "علاقات الاتحاد الأوروبي وموريشيوس",
    "mexico–european union relations": "علاقات الاتحاد الأوروبي والمكسيك",
    "moldova–european union relations": "علاقات الاتحاد الأوروبي ومولدوفا",
    "mongolia–european union relations": "علاقات الاتحاد الأوروبي ومنغوليا",
    "montenegro–european union relations": "علاقات الاتحاد الأوروبي والجبل الأسود",
    "morocco–european union relations": "علاقات الاتحاد الأوروبي والمغرب",
    "namibia–european union relations": "علاقات الاتحاد الأوروبي وناميبيا",
    "nepal–european union relations": "علاقات الاتحاد الأوروبي ونيبال",
    "new zealand–european union relations": "علاقات الاتحاد الأوروبي ونيوزيلندا",
    "nicaragua–european union relations": "علاقات الاتحاد الأوروبي ونيكاراغوا",
    "north korea–european union relations": "علاقات الاتحاد الأوروبي وكوريا الشمالية",
    "north macedonia–european union relations": "علاقات الاتحاد الأوروبي ومقدونيا الشمالية",
    "norway–european union relations": "علاقات الاتحاد الأوروبي والنرويج",
    "pakistan–european union relations": "علاقات الاتحاد الأوروبي وباكستان",
    "palau–european union relations": "علاقات الاتحاد الأوروبي وبالاو",
    "palestine–european union relations": "علاقات الاتحاد الأوروبي وفلسطين",
    "papua new guinea–european union relations": "علاقات الاتحاد الأوروبي وبابوا غينيا الجديدة",
    "philippines–european union relations": "علاقات الاتحاد الأوروبي والفلبين",
    "qatar–european union relations": "علاقات الاتحاد الأوروبي وقطر",
    "russia–european union relations": "علاقات الاتحاد الأوروبي وروسيا",
    "samoa–european union relations": "علاقات الاتحاد الأوروبي وساموا",
    "san marino–european union relations": "علاقات الاتحاد الأوروبي وسان مارينو",
    "saudi arabia–european union relations": "علاقات الاتحاد الأوروبي والسعودية",
    "serbia–european union relations": "علاقات الاتحاد الأوروبي وصربيا",
    "sierra leone–european union relations": "علاقات الاتحاد الأوروبي وسيراليون",
    "singapore–european union relations": "علاقات الاتحاد الأوروبي وسنغافورة",
    "somalia–european union relations": "علاقات الاتحاد الأوروبي والصومال",
    "south africa–european union relations": "علاقات الاتحاد الأوروبي وجنوب إفريقيا",
    "south korea–european union relations": "علاقات الاتحاد الأوروبي وكوريا الجنوبية",
    "sri lanka–european union relations": "علاقات الاتحاد الأوروبي وسريلانكا",
    "switzerland–european union relations": "علاقات الاتحاد الأوروبي وسويسرا",
    "syria–european union relations": "علاقات الاتحاد الأوروبي وسوريا",
    "taiwan–european union relations": "علاقات الاتحاد الأوروبي وتايوان",
    "tanzania–european union relations": "علاقات الاتحاد الأوروبي وتنزانيا",
    " gambia–european union relations": "علاقات الاتحاد الأوروبي وغامبيا",
    "tonga–european union relations": "علاقات الاتحاد الأوروبي وتونغا",
    "tunisia–european union relations": "علاقات الاتحاد الأوروبي وتونس",
    "turkey–european union relations": "علاقات الاتحاد الأوروبي وتركيا",
    "turkmenistan–european union relations": "علاقات الاتحاد الأوروبي وتركمانستان",
    "uganda–european union relations": "علاقات أوغندا والاتحاد الأوروبي",
    "ukraine–european union relations": "علاقات أوكرانيا والاتحاد الأوروبي",
    "united kingdom–european union relations": "علاقات الاتحاد الأوروبي والمملكة المتحدة",
    "united states–european union relations": "علاقات الاتحاد الأوروبي والولايات المتحدة",
    "uzbekistan–european union relations": "علاقات أوزبكستان والاتحاد الأوروبي",
    "venezuela–european union relations": "علاقات الاتحاد الأوروبي وفنزويلا",
    "yemen–european union relations": "علاقات الاتحاد الأوروبي واليمن",
    "zambia–european union relations": "علاقات الاتحاد الأوروبي وزامبيا",
    "zimbabwe–european union relations": "علاقات الاتحاد الأوروبي وزيمبابوي",
}


@pytest.mark.parametrize("category, expected", ireland_test_data.items(), ids=ireland_test_data.keys())
@pytest.mark.fast
def test_ireland_test_data(category: str, expected: str) -> None:
    label = new_relations_resolvers(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", test_data.items(), ids=test_data.keys())
@pytest.mark.fast
def test_work_relations_new(category: str, expected: str) -> None:
    label = new_relations_resolvers(category)
    assert label == expected


TEMPORAL_CASES = [
    ("test_work_relations_new", test_data, new_relations_resolvers),
    ("test_work_relations_ireland", ireland_test_data, new_relations_resolvers),
]


@pytest.mark.parametrize("name,data,callback", TEMPORAL_CASES)
@pytest.mark.dump
def test_dump_all(name: str, data: str, callback: str) -> None:
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, f"test_new_relations_resolvers_big_data_{name}")

    # dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""
Tests
"""

from typing import Callable

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.countries_names_resolvers.countries_names import resolve_by_countries_names

political_data_v1 = {
    "west india political leader": "قادة الهند الغربية السياسيون",
    "australia political leader": "قادة أستراليا السياسيون",
    "japan political leader": "قادة اليابان السياسيون",
    "mauritius political leader": "قادة موريشيوس السياسيون",
    "morocco political leader": "قادة المغرب السياسيون",
    "rwanda political leader": "قادة رواندا السياسيون",
    "syria political leader": "قادة سوريا السياسيون",
    "tunisia political leader": "قادة تونس السياسيون",
}

main_data = {
    "uzbekistan afc asian cup squad": "تشكيلات أوزبكستان في كأس آسيا",
    "china afc women's asian cup squad": "تشكيلات الصين في كأس آسيا للسيدات",
    "democratic-republic-of-congo winter olympics squad": "تشكيلات جمهورية الكونغو الديمقراطية في الألعاب الأولمبية الشتوية",
    "democratic-republic-of-congo summer olympics squad": "تشكيلات جمهورية الكونغو الديمقراطية في الألعاب الأولمبية الصيفية",
    "west india olympics squad": "تشكيلات الهند الغربية في الألعاب الأولمبية",
    "victoria-australia fifa futsal world cup squad": "تشكيلات فيكتوريا (أستراليا) في كأس العالم لكرة الصالات",
    "victoria-australia fifa world cup squad": "تشكيلات فيكتوريا (أستراليا) في كأس العالم",
    "yemen afc asian cup squad": "تشكيلات اليمن في كأس آسيا",
    "yemen afc women's asian cup squad": "تشكيلات اليمن في كأس آسيا للسيدات",
    "democratic-republic-of-congo winter olympics": "جمهورية الكونغو الديمقراطية في الألعاب الأولمبية الشتوية",
    "west india summer olympics": "الهند الغربية في الألعاب الأولمبية الصيفية",
    "tunisia presidents": "رؤساء تونس",
    "tunisia government": "حكومة تونس",
    "tunisia territorial judges": "قضاة أقاليم تونس",
    "tunisia territorial officials": "مسؤولو أقاليم تونس",
    "yemen board members": "أعضاء مجلس اليمن",
    "yemen government": "حكومة اليمن",
    "yemen elections": "انتخابات اليمن",
    "yemen war": "حرب اليمن",
    "yemen responses": "استجابات اليمن",
    "yemen executive cabinet": "مجلس وزراء اليمن التنفيذي",
    "yemen presidents": "رؤساء اليمن",
    "yemen conflict": "نزاع اليمن",
    "yemen cup": "كأس اليمن",
    "victoria-australia elections": "انتخابات فيكتوريا (أستراليا)",
    "victoria-australia executive cabinet": "مجلس وزراء فيكتوريا (أستراليا) التنفيذي",
    "victoria-australia government": "حكومة فيكتوريا (أستراليا)",
    "west india government personnel": "موظفي حكومة الهند الغربية",
    "west india presidents": "رؤساء الهند الغربية",
    "west india responses": "استجابات الهند الغربية",
    "democratic-republic-of-congo territorial judges": "قضاة أقاليم جمهورية الكونغو الديمقراطية",
    "democratic-republic-of-congo territorial officials": "مسؤولو أقاليم جمهورية الكونغو الديمقراطية",
    "democratic-republic-of-congo war": "حرب جمهورية الكونغو الديمقراطية",
    "united states elections": "انتخابات الولايات المتحدة",
    "england war and conflict": "حروب ونزاعات إنجلترا",
    "england war": "حرب إنجلترا",
    "georgia government": "حكومة جورجيا",
    "israel war and conflict": "حروب ونزاعات إسرائيل",
    "israel war": "حرب إسرائيل",
    "oceania cup": "كأس أوقيانوسيا",
    "spain war and conflict": "حروب ونزاعات إسبانيا",
    "spain war": "حرب إسبانيا",
}


@pytest.mark.parametrize("category, expected", main_data.items(), ids=main_data.keys())
@pytest.mark.fast
def test_resolve_by_countries_names(category: str, expected: str) -> None:
    label = resolve_by_countries_names(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", political_data_v1.items(), ids=political_data_v1.keys())
@pytest.mark.fast
def test_political_data_v1(category: str, expected: str) -> None:
    label = resolve_by_countries_names(category)
    assert label == expected


TEMPORAL_CASES = [
    ("test_resolve_by_countries_names", main_data, resolve_by_countries_names),
    ("test_political_data_v1", political_data_v1, resolve_by_countries_names),
]


@pytest.mark.dump
@pytest.mark.parametrize("name,data, callback", TEMPORAL_CASES)
def test_all_dump(name: str, data: dict[str, str], callback: Callable) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data = {
    "Category:Mosque buildings with domes in India": "تصنيف:مساجد بقباب في الهند",
    "Category:Mosque buildings with domes in Iran": "تصنيف:مساجد بقباب في إيران",
    "Category:Mosque buildings with minarets in India": "تصنيف:مساجد بمنارات في الهند",
    "Category:Mosque buildings with minarets in Iran": "تصنيف:مساجد بمنارات في إيران",
}


@pytest.mark.parametrize("category, expected", data.items(), ids=data.keys())
@pytest.mark.fast
def test_mosques(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


TEMPORAL_CASES = [
    ("test_mosques", data),
]


@pytest.mark.parametrize("name,data", TEMPORAL_CASES)
@pytest.mark.dump
def test_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
